      SUBROUTINE EVCALC
C***********************************************************************
C                 EVCALC Module of ISC2 Short Term EVENT Model - ISCEV2
C
C        PURPOSE: Controls Flow and Processing of CALCulation Modules
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Arrays of Source Parameters
C                 Arrays of Receptor Locations
C                 Meteorological Variables for One Hour
C
C        OUTPUTS: Array of 1-hr CONC or DEPOS Values for Each Source/Receptor
C
C        CALLED FROM:   EVLOOP
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'EVCALC'
      PATH   = 'CN'

C     Begin Source LOOP
      DO 20 ISRC = 1, NUMSRC
         IF (IGROUP(ISRC,IDXEV(IEVENT)) .EQ. 1) THEN
            IF (SRCTYP(ISRC) .EQ. 'POINT') THEN
C              Calculate Point Source Values                ---   CALL PCALC2
               CALL PCALC2
            ELSE IF (SRCTYP(ISRC) .EQ. 'VOLUME') THEN
C              Calculate Volume Source Values               ---   CALL VCALC2
               CALL VCALC2
            ELSE IF (SRCTYP(ISRC) .EQ. 'AREA') THEN
C              Calculate Area Source Values                 ---   CALL ACALC2
               CALL ACALC2
            ELSE IF (SRCTYP(ISRC) .EQ. 'OPENPIT') THEN
C              Calculate OpenPit Source Values              ---   CALL OCALC2
               CALL OCALC2
            END IF
         END IF
 20   CONTINUE
C     End Source LOOP

      RETURN
      END

      SUBROUTINE PCALC2
C***********************************************************************
C                 PCALC2 Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates concentration or deposition values
C                 for POINT sources
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C
C        MODIFIED BY D. Strimaitis, SRC (for Wet & Dry DEPOSITION)
C        MODIFIED BY D. Strimaitis, SRC (for COMPLEX I -Intermediate
C                                        Terrain Processing)
C
C        DATE:    December 15, 1993
C
C        MODIFIED:   To add call for new source type of OPENPIT.
C                    R. W. Brode, PES - 9/30/94
C
C        MODIFIED BY D. Strimaitis, SRC (for Dry DEPOSITION)
C        (DATE:    February 15, 1993)
C
C        INPUTS:  Source Parameters for Specific Source
C                 Arrays of Receptor Locations
C                 Meteorological Variables for One Hour
C
C        OUTPUTS: 1-hr CONC or DEPOS Values for Each Receptor for
C                 Particular Source
C
C        CALLED FROM:   CALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'PCALC2'

C     Set the Source Variables for This Source              ---   CALL SETSRC
      CALL SETSRC

C     Apply Variable Emission Rate and Unit Factors         ---   CALL EMFACT
      CALL EMFACT(QS)

C     Set Particle Deposition Variables for this Source
      IF (LDPART .OR. LWPART) THEN
C        Calculate Deposition Velocities for this Source    ---   CALL VDP
         CALL VDP
      END IF

C     Calculate Scavenging Ratios for this Source           ---   CALL SCAVRAT
      IF (LWPART .OR. LWGAS) CALL SCAVRAT

      IF ((QTK.NE.0.0) .AND. (STABLE .OR. (HS.LE.ZI) .OR.
     &                        DEPOS .OR. WDEP)) THEN
C        Calculate Buoyancy and Momentum Fluxes
         IF (TS .LT. TA)  TS = TA
         FB = (0.25/TS)*(VS*DS*DS)*G*(TS-TA)
         FM = (0.25/TS)*(VS*DS*DS)*VS*TA
C        Adjust Wind Speed to Stack Height                  ---   CALL WSADJ
         CALL WSADJ
C        Calculate Distance to Final Rise                   ---   CALL DISTF
         CALL DISTF
C        Set Wake and Building Type Switches                ---   CALL WAKFLG
         CALL WAKFLG
C        Initialize FSTREC Logical Switch for First Receptor of Loop
         FSTREC = .TRUE.
C        Initialize FSTREC Logical Switch for First CMP1 Receptor of Loop
         FSTCMP = .TRUE.
         IF (LDPART .OR. LWPART) THEN
C           Calculate Min Sigma-z for Settled Plume @ Surface --- CALL SETSZMN
            CALL SETSZMN
         END IF

CXXXC        Begin Receptor LOOP

CXXX         DO 2000 IREC = 1, NUMREC
C           Calculate Down and Crosswind Distances          ---   CALL XYDIST
            CALL XYDIST
            IF (ABS(Y) .GT. 1.191754*X) THEN
C              Receptor is at least 50 deg. off the plume centerline
               DO ITYP = 1, NUMTYP
                  HRVAL(ITYP) = 0.0
               END DO
            ELSE IF (DISTR .LT. 0.99 .OR. DISTR .LT. 3.*ZLB) THEN
C              Receptor Too Close to Source for Calculation
               DO ITYP = 1, NUMTYP
                  HRVAL(ITYP) = 0.0
               END DO
            ELSE

CRWB           Modifications to Integrate COMPLEX1 Algorithms.
CRWB           Get Plume Heights and Check for INTERMEDIATE TERRAIN Regime
               IF (NOCMPL) THEN
                  CALL PHEFF(X,DHP,HEFLAT)
                  CALL STERAD(HEFLAT,ZELEV,HE)
                  SIMPLE = .TRUE.
                  INTERM = .FALSE.
                  COMPLX = .FALSE.
C                 Set HECOMP = HEFLAT for later check versus ZI
                  HECOMP = HEFLAT
               ELSE IF (NOSMPL) THEN
C                 Note: Use radial distance, DISTR, for COMPLEX1 plume height.
                  CALL PHEFFC(DISTR,DHPCMP,HECOMP)
                  CALL CTERAD(HECOMP,ZELEV,HECMP1,CORR)
                  COMPLX = .TRUE.
                  INTERM = .FALSE.
                  SIMPLE = .FALSE.
C                 Set HEFLAT = HECOMP for later check versus ZI
                  HEFLAT = HECOMP
               ELSE
                  CALL PHEFF(X,DHP,HEFLAT)
                  CALL STERAD(HEFLAT,ZELEV,HE)
                  IF (ELEV) THEN
                     CALL PHEFFC(DISTR,DHPCMP,HECOMP)
                     CALL CTERAD(HECOMP,ZELEV,HECMP1,CORR)
C                    Set the Simple/Intermediate/Complex Terrain Flags
                     CALL ITSET
                  ELSE
                     SIMPLE = .TRUE.
                     HECOMP = HEFLAT
                  END IF
               END IF

               IF (STABLE .OR. (HEFLAT.LE.ZI) .OR. (HECOMP.LE.ZI) .OR.
     &             DEPOS  .OR.  WDEP) THEN

                  IF (SIMPLE .OR. INTERM) THEN
C                    Determine Simple Terrain Sigmas        ---   CALL PDIS
                     CALL PDIS(X,SY,SZ,XY,XZ,SBID)
                  END IF
                  IF (COMPLX .OR. INTERM) THEN
C                    Determine Complex Terrain Sigmas       ---   CALL PDISC
                     CALL PDISC(DISTR,SZCMP1,XZCMP1,SBCMP1)
                  END IF


C                 Determine Deposition Correction Factors for Gases
                  IF (LWGAS) THEN
C                    Initialize wet source depletion factor to unity.
                     WQCORG = 1.
                     WQCORGC = 1.
                     IF (WDPLETE) THEN
C                       Determine source depletion factor
C                       from wet removal (GASES)
                        IF (SIMPLE .OR. INTERM) THEN
C                          Simple Terrain Model
                           WQCORG = EXP(-GSCVRT*X/US)
                        ENDIF
                        IF (COMPLX .OR. INTERM) THEN
C                          Complex Terrain Model - use radial distance
                           WQCORGC = EXP(-GSCVRT*DISTR/US)
                        ENDIF
                     ENDIF
                  ENDIF

C                 Apply Intermediate Terrain Logic
                  IF (SIMPLE) THEN
C                    Simple Terrain Model Only              ---   CALL PSIMPL
                     CALL PSIMPL
                  ELSE IF (COMPLX) THEN
C                    Complex Terrain Model Only             ---   CALL PCOMPL
                     CALL PCOMPL
                  ELSE IF (INTERM) THEN
C                    Initialize simple and complex terrain holding variables
                     SIMCON = 0.0
                     COMCON = 0.0
                     DO ITYP = 1, NUMTYP
                        SIMPL(ITYP) = 0.
                        COMPL(ITYP) = 0.
                     END DO
C                    Determine Which Model Predicts the Larger Conc.
C                    Save Simple Terrain Conc.           ---   CALL PSIMPL
                     CALL PSIMPL
                     DO ITYP = 1, NUMTYP
                        SIMPL(ITYP) = HRVAL(ITYP)
                     END DO
C                    Save Complex Terrain Conc.          ---   CALL PCOMPL
                     CALL PCOMPL
                     DO ITYP = 1, NUMTYP
                        COMPL(ITYP) = HRVAL(ITYP)
                     END DO
C                    Report Result for Model that Produces the Larger
C                    Concentration
                     IF (SIMCON .GE. COMCON) THEN
                        DO ITYP = 1, NUMTYP
                           HRVAL(ITYP) = SIMPL(ITYP)
                        END DO
                     ELSE
                        DO ITYP = 1, NUMTYP
                           HRVAL(ITYP) = COMPL(ITYP)
                        END DO
                     END IF
                  END IF

C                 Sum HRVAL to AVEVAL and ANNVAL Arrays  ---   CALL SUMVAL
                  CALL SUMVAL

               ELSE
                  DO ITYP = 1, NUMTYP
                     HRVAL(ITYP) = 0.0
                  END DO
               END IF

C              Write DEBUG Information related to Terrain and Removal
               IF (DEBUG) THEN
                  WRITE(IOUNIT,*)
                  WRITE(IOUNIT,*) 'HOUR, EVENT: ',IHOUR,IEVENT
                  WRITE(IOUNIT,*) 'PCALC: HRVAL(final) = ',HRVAL
                 IF (LDPART .OR. LWPART) THEN
                  WRITE(IOUNIT,*) 'PCALC: Particle Removal --------'
                  WRITE(IOUNIT,*) 'WQCOR  = ',(WQCOR(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'WQCORC = ',(WQCORC(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'DQCOR  = ',(DQCOR(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'DQCORC = ',(DQCORC(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'PCORZD = ',(PCORZD(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'PCORZDC= ',(PCORZDC(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'PCORZR = ',(PCORZR(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'PCORZRC= ',(PCORZRC(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'SZCOR  = ',(SZCOR(I),I=1,NPD)
                  WRITE(IOUNIT,*) 'SZCORC = ',(SZCORC(I),I=1,NPD)
                 ENDIF
                  WRITE(IOUNIT,*) 'PCALC: Gas Removal -------------'
                  WRITE(IOUNIT,*) 'WQCORG, WQCORGC = ',WQCORG,WQCORGC
                  WRITE(IOUNIT,*) 'PCALC: Concentration -----------'
                  WRITE(IOUNIT,*) 'SIMPL, COMPL    = ',SIMPL,COMPL
               END IF

            END IF
CXXX 2000    CONTINUE
CXXXC        End Receptor LOOP
      END IF

      RETURN
      END


      SUBROUTINE ITSET
C***********************************************************************
C                 ITSET Module of the ISC Short Term Model - Version 2
C
C        PURPOSE:    To set intermediate terrain variables, based on
C                    complex terrain plume height and terrain height.
C
C        PROGRAMMER: Roger W. Brode, PES, Inc.
C
C        DATE:       September 30, 1994
C
C        INPUTS:     HECOMP = Complex Terrain Plume Height, without
C                             Terrain Adjustment Factors (through COMMON)
C
C        OUTPUTS:    SIMPLE, COMPLX, INTERM = Intermediate terrain
C                    logical control variables (through COMMON)
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'ITSET'
      SIMPLE = .FALSE.
      INTERM = .FALSE.
      COMPLX = .FALSE.

      IF (HS .GE. HTER) THEN
         SIMPLE = .TRUE.
      ELSE IF (HECOMP .GT. HTER) THEN
         INTERM = .TRUE.
      ELSE
         COMPLX = .TRUE.
      END IF

C     Write Special DEBUG values for IT results
      if(DEBUG) then
         write(iounit,*)
         write(iounit,*) 'ITSET --- IT RESULTS, HOUR :',IHOUR
         IF (SIMPLE) THEN
            write(iounit,*) 'ITFLAG = SIMPLE'
         ELSE IF (INTERM) THEN
            write(iounit,*) 'ITFLAG = INTERM'
         ELSE IF (COMPLX) THEN
            write(iounit,*) 'ITFLAG = COMPLX'
         END IF
         write(iounit,*) 'HECOMP         = ',HECOMP
         write(iounit,*) 'HS, ZS, ZELEV  = ',HS,ZS,ZELEV
      endif

      RETURN
      END

      SUBROUTINE VCALC2
C***********************************************************************
C                 VCALC2 Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates concentration or deposition values
C                 for VOLUME sources
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C
C        MODIFIED BY D. Strimaitis, SRC (for Wet & Dry DEPOSITION)
C
C        DATE:    December 15, 1993
C
C        MODIFIED BY D. Strimaitis, SRC (for Dry DEPOSITION)
C        (DATE:    February 15, 1993)
C
C        MODIFIED BY R. Brode, PES, to initialize SBID - 7/15/94
C
C        INPUTS:  Source Parameters for Specific Source
C                 Arrays of Receptor Locations
C                 Meteorological Variables for One Hour
C
C        OUTPUTS: 1-hr CONC or DEPOS Values for Each Receptor for
C                 Particular Source
C
C        CALLED FROM:   CALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'VCALC2'

C     Set the Source Variables for This Source              ---   CALL SETSRC
      CALL SETSRC

C     Apply Variable Emission Rate and Unit Factors         ---   CALL EMFACT
      CALL EMFACT(QS)

C     Set Particle Deposition Variables for this Source
      IF (LDPART .OR. LWPART) THEN
C        Calculate Deposition Velocities for this Source    ---   CALL VDP
         CALL VDP
      END IF

C     Calculate Scavenging Ratios for this Source           ---   CALL SCAVRAT
      IF (LWPART .OR. LWGAS) CALL SCAVRAT

      IF ((QTK.NE.0.0) .AND. (STABLE .OR. (HS.LE.ZI) .OR.
     &                        DEPOS .OR. WDEP)) THEN
C        Adjust Wind Speed to Release Height                ---   CALL WSADJ
         CALL WSADJ
C        Calculate Effective Radius
         XRAD = 2.15*SYINIT
         IF (LDPART .OR. LWPART) THEN
C           Calculate Min Sigma-z for Settled Plume @ Surface --- CALL SETSZMN
            CALL SETSZMN
         END IF
C        Initialize SBID to 0.0 for call to DEPCOR
         SBID = 0.0

CXXXC        Begin Receptor LOOP
CXXX         DO 20 IREC = 1, NUMREC
C           Calculate Down and Crosswind Distances          ---   CALL XYDIST
            CALL XYDIST
            IF (ABS(Y) .GT. 1.191754*X) THEN
C              Receptor is at least 50 deg. off the plume centerline
               DO ITYP = 1, NUMTYP
                  HRVAL(ITYP) = 0.0
               END DO
            ELSE IF (DISTR .LT. (XRAD+0.99)) THEN
C              Receptor Too Close to Source for Calculation
               DO ITYP = 1, NUMTYP
                  HRVAL(ITYP) = 0.0
               END DO
            ELSE IF ((X-XRAD) .LT. 0.0) THEN
C              Receptor Upwind of Downwind Edge
               DO ITYP = 1, NUMTYP
                  HRVAL(ITYP) = 0.0
               END DO
            ELSE
C              Determine Effective Plume Height             ---   CALL VHEFF
               CALL VHEFF(ZELEV,HEFLAT,HE)
C              Determine Dispersion Parameters              ---   CALL VDIS
               CALL VDIS(X,SY,SZ,XY,XZ)
               IF (LWGAS) THEN
C                 Initialize wet source depletion factor to unity.
                  WQCORG = 1.
                  IF (WDPLETE) THEN
C                    Determine source depletion factor
C                    from wet removal (GASES)
                     WQCORG=EXP(-GSCVRT*X/US)
                  ENDIF
               ENDIF
C              Calculate Conc. or Depos. for Virtual Point Source
C              Using a Simple Terrain Model                 ---   CALL PSIMPL
               CALL PSIMPL

C              Sum HRVAL to AVEVAL and ANNVAL Arrays     ---   CALL SUMVAL
               CALL SUMVAL

            END IF
CXXX 20      CONTINUE
CXXXC        End Receptor LOOP
      END IF

      RETURN
      END


      SUBROUTINE ACALC2
C***********************************************************************
C                 ACALC2 Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates concentration or deposition values
C                 for AREA sources utilizing an integrated line source.
C
C        PROGRAMMER: Jeff Wang, Roger Brode
C
C        MODIFIED BY D. Strimaitis, SRC (for Wet & Dry DEPOSITION)
C
C        DATE:    November 8, 1993
C
C        MODIFIED by YICHENG ZHUANG, SRC to combine version 93188 with
C                 version 93046 - 9/28/93
C
C        MODIFIED:   To incorporate numerical integration algorithm
C                    for AREA source - 7/7/93
C
C        MODIFIED BY D. Strimaitis, SRC (for DEPOSITION) - 2/15/93
C
C        MODIFIED BY R. Brode, PES, to initialize XZ, XY, and SBID - 7/15/94
C
C*       MODIFIED BY J. Hardikar, PES, to make consistent with the new
C*                   OPENPIT Source Methodology - 7/20/94
C
C
C        INPUTS:  Source Parameters for Specific Source
C                 Arrays of Receptor Locations
C                 Meteorological Variables for One Hour
C
C        OUTPUTS: Array of 1-hr CONC or DEPOS Values for Each Source/Receptor
C
C        CALLED FROM:   CALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      
      REAL XSPA(NVMAX),YSPA(NVMAX)
      
C     Variable Initializations
      MODNAM = 'ACALC2'

C     Set the Source Variables for This Source              ---   CALL SETSRC
      CALL SETSRC

C     Apply Variable Emission Rate and Unit Factors         ---   CALL EMFACT
      CALL EMFACT(QS)

C     Set Particel Deposition Variables for this Source
      IF (LDPART .OR. LWPART) THEN
C        Calculate Deposition Velocities for this Source    ---   CALL VDP
         CALL VDP
      END IF

C     Calculate Scavenging Ratios for this Source           ---   CALL SCAVRAT
      IF (LWPART .OR. LWGAS) CALL SCAVRAT

      IF ((QTK.NE.0.0) .AND. (STABLE .OR. (HS.LE.ZI))) THEN
C        Determine Coordinates of Vertices for AREA Source
C        in Wind Direction Coordinate System                ---   CALL AVERTS
         CALL AVERTS(XVERT,YVERT,XSPA,YSPA,NVERT+1)

C*       Store Coordinates of the Area in COMMON Variables
         DO 40 IVERT = 1,NVERT+1
            SPA(IVERT,1) = XSPA(IVERT)
            SPA(IVERT,2) = YSPA(IVERT)
40       CONTINUE
         
C        Adjust Wind Speed to Release Height                ---   CALL WSADJ
         CALL WSADJ
         IF (LDPART .OR. LWPART) THEN
C           Calculate Min Sigma-z for Settled Plume @ Surface --- CALL SETSZMN
            CALL SETSZMN
         END IF
C*       Initialize XY and XZ to 0.0 (XZ is used in
C*       call to DEPCOR from PLUMEF)
         XY = 0.0
         XZ = 0.0
         
C        Initialize SBID to 0.0 (for call to DEPCOR from PLUMEF)
         SBID = 0.0

CXXXC        Begin Receptor LOOP
CXXX         DO 660 IREC = 1, NUMREC
C           Calculate Down and Crosswind Distances          ---   CALL XYDIST
            CALL XYDIST
            HE = HS
            HEFLAT = HE
            IF (STABLE .OR. (HEFLAT.LE.ZI) .OR. DEPOS .OR. WDEP) THEN
               DO ITYP = 1, NUMTYP
C                 Calculate Area Source Integral            ---   CALL AREAIN
                  CALL AREAIN
               END DO
            ELSE
C              Plume Is Above Mixing Height, ZI, and No Wet Deposition
               DO ITYP = 1, NUMTYP
                  HRVAL(ITYP) = 0.0
               END DO
            END IF

C           Sum HRVAL to AVEVAL and ANNVAL Arrays        ---   CALL SUMVAL
            CALL SUMVAL

CXXX 660     CONTINUE
CXXXC        End Receptor LOOP
      END IF

      RETURN
      END


      SUBROUTINE OCALC2
C***********************************************************************
C                 OCALC2 Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates concentration or deposition values
C                 for OPENPIT sources
C
C        PROGRAMMER: Jayant Hardikar, Roger Brode
C        ADAPTED FROM:  SUBROUTINE ACALC
C
C        DATE:    July 19, 1994
C
C        MODIFIED:   To skip calculations if QPTOT = 0.0, avoiding
C                    zero divide error in SUB. AMFRAC.
C                    R. W. Brode, PES Inc., - 4/14/95
C
C        INPUTS:  Source Parameters for Specific Source
C                 Arrays of Receptor Locations
C                 Meteorological Variables for One Hour
C
C        OUTPUTS: Array of 1-hr CONC or DEPOS Values for Each Source/Receptor
C
C        CALLED FROM:   CALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      REAL XVM(5), YVM(5)

C     Variable Initializations
      MODNAM = 'OCALC2'

C     Set the Source Variables for This Source              ---   CALL SETSRC
      CALL SETSRC

C*    Initialize the Total Adjusted Emission Rate from
C*    All Particles
      QPTOT = 0.0          

C*    Loop over Particle Size Categories
      DO 20 ICAT = 1,NPD
C*       Calculate the Escape Fraction for Each Category    ---   CALL ESCAPE      
         CALL ESCAPE(ICAT)

C*       Adjust the Emission Rate for Each Category         ---   CALL ADJEMI
         CALL ADJEMI(ICAT,QPTOT)

C*    End Loop Over Particle Size Categories
20    CONTINUE

C*    Skip Calculations if QPTOT = 0.0
      IF (QPTOT .EQ. 0.0)  GO TO 999

C*    Adjust the Mass Fractions for All the Particle 
C*    Size Categories                                       ---   CALL AMFRAC
      CALL AMFRAC(QPTOT)
      
C*    Determine the AlongWind Length of the OPENPIT Source  ---   CALL LWIND
      CALL LWIND

C*    Calculate the Relative Depth of the OPENPIT Source    ---   CALL PDEPTH            
      CALL PDEPTH
      
C*    Calculate the Fractional Size of the 
C*    Effective Pit Area                                    ---   CALL PTFRAC
      CALL PTFRAC


C*    WRITE DEBUG INFORMATION
      IF (DEBUG) THEN
         WRITE (IOUNIT,*)
         WRITE (IOUNIT,*)
         WRITE (IOUNIT,*) 'DETAIL INFORMATION ON THE OPENPIT SOURCE:'
         WRITE (IOUNIT,*)
         WRITE (IOUNIT,*)   
      ENDIF
     
C*    Determine the Coordinates of the Effective Pit Area
C*    in Wind Direction Coordinate System                   ---   CALL PITEFF
      CALL PITEFF

C*    Calculate the Emission Rate for the Effective
C*    Pit Area                                              ---   CALL PITEMI
      CALL PITEMI(QPTOT)

C*    WRITE DEBUG INFORMATION
      IF (DEBUG) THEN
         WRITE (IOUNIT,*) 'OPENPIT PARTICLE CHARACTERISTICS:'
         WRITE (IOUNIT,*) '-------------------------------'
         WRITE (IOUNIT,*) 
         WRITE (IOUNIT,8000) (EFRAC(II),II = 1, NPD)
8000     FORMAT (1X,'ESCAPE FRACTIONS= ',10(F8.3,2X))
         WRITE (IOUNIT,8200) (QPART(II),II = 1, NPD)
8200     FORMAT (1X,'ADJUSTED EMISSION RATES= ',10(F8.3,2X))
         WRITE (IOUNIT,8400) (PHI(II),II = 1, NPD)
8400     FORMAT (1X,'ADJUSTED MASS FRACTIONS= ',10(F8.3,2X))
         WRITE (IOUNIT,*) 'EMISSION RATE OF EFFECTIVE PIT= ',QEFF
         WRITE (IOUNIT,*) 
      ENDIF                  
      
                  
C     Set Particel Deposition Variables for this Source
      IF (LDPART .OR. LWPART) THEN
C        Calculate Deposition Velocities for this Source    ---   CALL VDP
         CALL VDP
      END IF

C     Calculate Scavenging Ratios for this Source           ---   CALL SCAVRAT
      IF (LWPART .OR. LWGAS) CALL SCAVRAT

C     Apply Variable Emission Rate and Unit Factors         ---   CALL EMFACT
      CALL EMFACT(QEFF)

      IF ((QTK.NE.0.0) .AND. (STABLE .OR. (HS.LE.ZI))) THEN
C        Adjust Wind Speed to Release Height                ---   CALL WSADJ
         CALL WSADJ
         IF (LDPART .OR. LWPART) THEN
C           Calculate Min Sigma-z for Settled Plume @ Surface --- CALL SETSZMN
            CALL SETSZMN
         END IF
C        Initialize XY and XZ to 0.0 (XZ is used in call to DEPCOR from PLUMEF)
         XY = 0.0
         XZ = 0.0
C        Initialize SBID to 0.0 (for call to DEPCOR from PLUMEF)
         SBID = 0.0
CXXXC        Begin Receptor LOOP
CXXX         DO 660 IREC = 1, NUMREC
C           Check for receptor located inside boundary of open pit source
            XVM(1) = XVERT(1) * 1000.
            XVM(2) = XVERT(2) * 1000.
            XVM(3) = XVERT(3) * 1000.
            XVM(4) = XVERT(4) * 1000.
            XVM(5) = XVERT(5) * 1000.
            YVM(1) = YVERT(1) * 1000.
            YVM(2) = YVERT(2) * 1000.
            YVM(3) = YVERT(3) * 1000.
            YVM(4) = YVERT(4) * 1000.
            YVM(5) = YVERT(5) * 1000.
            XR = AXR(IEVENT)
            YR = AYR(IEVENT)
            CALL PNPOLY(XR,YR,XVM,YVM,5,INOUT)
            IF (INOUT .GT. 0) THEN
C              Receptor is within boundary - skip to next receptor
               GO TO 660
            END IF

C           Calculate Down and Crosswind Distances          ---   CALL XYDIST
            CALL XYDIST
            HE = HS
            HEFLAT = HE
            IF (STABLE .OR. (HEFLAT.LE.ZI) .OR. DEPOS .OR. WDEP) THEN
               DO ITYP = 1, NUMTYP
C                 Calculate Area Source Integral            ---   CALL AREAIN
                  CALL AREAIN
               END DO
            ELSE
C              Plume Is Above Mixing Height, ZI, and No Wet Deposition
               DO ITYP = 1, NUMTYP
                  HRVAL(ITYP) = 0.0
               END DO
            END IF

C           Sum HRVAL to AVEVAL and ANNVAL Arrays        ---   CALL SUMVAL
            CALL SUMVAL

 660     CONTINUE
CXXX 660     CONTINUE
CXXXC        End Receptor LOOP
      END IF

 999  RETURN
      END


      SUBROUTINE SETSRC
C***********************************************************************
C                 SETSRC Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Sets the Source Parameters for a Particular Source
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C
C        MODIFIED BY: D. Strimaitis, SRC (for Wet & Dry DEPOSITION)
C
C        DATE:  November 8,1993
C
C        MODIFIED by Yicheng Zhuang, SRC to combine version 93188 with
C                 version 93046 - 9/28/93
C
C        MODIFIED:   To incorporate inputs for numerical integration
C                    algorithm for AREA source - 7/7/93
C
C        MODIFIED BY D. Strimaitis, SRC (for DEPOSITION) - 2/15/93
C
C        MODIFIED BY Jayant Hardikar,PES (for handling OPENPIT 
C                    Source - 7/19/94 , also modified AREA Source
C                    for Consistency with OPENPIT Source)
C
C        MODIFIED BY Roger Brode, PES (modified data structure for
C                    AXVERT and AYVERT for consistency with other
C                    2-D source arrays) - 8/15/95
C
C        INPUTS:  Source Parameters Arrays
C                 Source Index
C
C        OUTPUTS: Source Parameters for a Particular Source
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'SETSRC'

C     Assign The Values From Array Elements To Variables
      IF (SRCTYP(ISRC) .EQ. 'POINT') THEN
         XS = AXS(ISRC)
         YS = AYS(ISRC)
         ZS = AZS(ISRC)
         QS = AQS(ISRC)
         HS = AHS(ISRC)

         DS = ADS(ISRC)
         VS = AVS(ISRC)
         TS = ATS(ISRC)

C        Check for Negative Stack Temperature, Used to Indicate Constant TS-TA
         IF (TS .LT. 0.0) THEN
            TS = TA + ABS(TS)
         END IF

         IF (IFVSEC .LE. NSEC) THEN
            DSBH = ADSBH(IFVSEC,ISRC)
            DSBW = ADSBW(IFVSEC,ISRC)
            IF (IDSWAK(IFVSEC,ISRC) .EQ. 0) THEN
               WAKLOW = .FALSE.
            ELSE IF (IDSWAK(IFVSEC,ISRC) .EQ. 1) THEN
               WAKLOW = .TRUE.
            END IF
         END IF

      ELSE IF (SRCTYP(ISRC) .EQ. 'VOLUME') THEN
         XS = AXS(ISRC)
         YS = AYS(ISRC)
         ZS = AZS(ISRC)
         QS = AQS(ISRC)
         HS = AHS(ISRC)

         SYINIT = ASYINI(ISRC)
         SZINIT = ASZINI(ISRC)

      ELSE IF (SRCTYP(ISRC) .EQ. 'AREA') THEN
         XS = AXS(ISRC)
         YS = AYS(ISRC)
         ZS = AZS(ISRC)
         QS = AQS(ISRC)
         HS = AHS(ISRC)

         XINIT = AXINIT(ISRC)
         YINIT = AYINIT(ISRC)
         ANGLE = AANGLE(ISRC)
         
         SZINIT = ASZINI(ISRC)         

         DO 15 IVERT = 1, NVERT+1
            XVERT(IVERT) = AXVERT(IVERT,ISRC)
            YVERT(IVERT) = AYVERT(IVERT,ISRC)
15       CONTINUE  
            

      ELSE IF (SRCTYP(ISRC) .EQ. 'OPENPIT') THEN
         XS = AXS(ISRC)
         YS = AYS(ISRC)
         ZS = AZS(ISRC)
         QS = AQS(ISRC)
C        Set Emission Height of Effective Area, HS = 0.0
         HS = 0.0
C        Set Height of Emissions Above Base of Pit, EMIHGT
         EMIHGT = AHS(ISRC)

         XINIT = AXINIT(ISRC)
         YINIT = AYINIT(ISRC)
         ANGLE = AANGLE(ISRC)
         PALPHA = AALPHA(ISRC)
         PDEFF  = APDEFF(ISRC)
         SZINIT = ASZINI(ISRC)
         PITLEN = AMAX1(XINIT,YINIT)
         PITWID = AMIN1(XINIT,YINIT)


         DO 20 IVERT = 1, NVERT+1
            XVERT(IVERT) = AXVERT(IVERT,ISRC)
            YVERT(IVERT) = AYVERT(IVERT,ISRC)
20       CONTINUE  
         
              
      END IF

      NPD = INPD(ISRC)
      IF (NPD .GT. 0) THEN
         DO 25 J = 1, NPD
            PDIAM(J) = APDIAM(J,ISRC)
            PHI(J) = APHI(J,ISRC)
            PDENS(J) = APDENS(J,ISRC)
            VGRAV(J) = AVGRAV(J,ISRC)
            TSTOP(J) = ATSTOP(J,ISRC)
            SC(J) = ASC(J,ISRC)
            PSCAV(J,1) = APSLIQ(J,ISRC)
            PSCAV(J,2) = APSICE(J,ISRC)
 25      CONTINUE
      END IF

C     Transfer Gas Wet Scavenging Coeff. (1:liquid, 2:frozen)
      GSCAV(1) = AGSCAV(1,ISRC)
      GSCAV(2) = AGSCAV(2,ISRC)

      RETURN
      END

      SUBROUTINE PHEFF(XARG,DHPOUT,HEOUT)
C***********************************************************************
C                 PHEFF Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Calculates Effective Plume Height for POINT Sources (m)
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C
C        DATE:    March 2, 1992
C
C        MODIFIED:   To remove terrain adjustment to separate subroutine,
C                    and to use calling arguments
C                    R.W. Brode, PES, Inc. - 9/30/94
C
C        INPUTS:  Arrays of Source Parameters
C                 Logical Wake Flags
C                 Meteorological Variables for One Hour
C                 Wind Speed Adjusted to Stack Height
C                 Downwind Distance
C                 Terrain Elevation of Receptor
C
C        OUTPUTS: Plume Height (HEOUT) without Terrain Adjustment
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'PHEFF'

C     Calculate Plume Height Without Terrain Adjustment
      IF ((.NOT. WAKE) .AND. (.NOT. GRDRIS)) THEN
C        Calculate Final Rise for First Receptor Only
         IF (FSTREC) THEN
            FSTREC = .FALSE.
            HSP = HSPRIM(US,VS,HS,DS)
C           Calculate Final Rise, DHF                       ---   CALL DELH
            CALL DELH(DHF)
         END IF
         IF (NOSTD) THEN
            HEOUT = HS + DHF
         ELSE
            HEOUT = HSP + DHF
         END IF
         IF (.NOT. NOBID) THEN
C           Calculate Gradual Plume Rise for Use in BID Calculation
            IF (XARG .LT. XF) THEN
C              Calculate Gradual Rise, DHPOUT               ---   CALL DHPHS
               CALL DHPHS(XARG,DHF,DHPOUT)
            ELSE
               DHPOUT = DHF
            END IF
         ELSE
            DHPOUT = DHF
         END IF
      ELSE IF (WAKE .AND. WAKESS) THEN
C        Calculate Final Rise for First Receptor Only
         IF (FSTREC) THEN
            FSTREC = .FALSE.
C           Calculate Final Rise (at X=XF), DHF             ---   CALL DHPSS
            CALL DHPSS(XF,DHPOUT)
            DHF    = DHPOUT
         END IF
         IF (XARG .LT. XF) THEN
C           Calculate Gradual Rise, DHP                     ---   CALL DHPSS
            CALL DHPSS(XARG,DHPOUT)
         ELSE
            DHPOUT = DHF
         END IF
         HEOUT = HS + DHPOUT
      ELSE
CRWB       if ((WAKE .AND. (.NOT. WAKESS)) .OR.
CRWB          ((.NOT. WAKE) .AND. GRDRIS)) then
C        Calculate Final Rise for First Receptor Only
         IF (FSTREC) THEN
            FSTREC = .FALSE.
            HSP = HSPRIM(US,VS,HS,DS)
C           Calculate Final Rise, DHF                       ---   CALL DELH
            CALL DELH(DHF)
         END IF
         IF (XARG .LT. XF) THEN
C           Calculate Gradual Rise, DHP                     ---   CALL DHPHS
            CALL DHPHS(XARG,DHF,DHPOUT)
         ELSE
            DHPOUT = DHF
         END IF
         IF (NOSTD) THEN
            HEOUT = HS + DHPOUT
         ELSE
            HEOUT = HSP + DHPOUT
         END IF
      END IF

      RETURN
      END

      SUBROUTINE PHEFFC(XARG,DHPOUT,HEOUT)
C***********************************************************************
C                 PHEFFC Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Calculates Effective Plume Height for POINT Sources (m)
C                 in Complex Terrain
C
C        PROGRAMMER: Roger Brode
C
C        DATE:    September 30, 1994
C
C        INPUTS:  Arrays of Source Parameters
C                 Logical Wake Flags
C                 Meteorological Variables for One Hour
C                 Wind Speed Adjusted to Stack Height
C                 Downwind Distance
C                 Terrain Elevation of Receptor
C
C        OUTPUTS: Plume Height (HEOUT) without Terrain Adjustment
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'PHEFFC'

      IF (FSTCMP) THEN
         FSTCMP = .FALSE.
C        This is the First Call for PHEFFC - Calculate HSP and DHFCMP
         HSP = HSPRIM(US,VS,HS,DS)
         CALL DELH(DHFCMP)
      END IF

      IF (XARG .LT. XF) THEN
C        Distance is less than distance to final rise - Calculate gradual rise
         CALL DHPHS(XARG,DHFCMP,DHPOUT)
      ELSE
C        Set gradual rise = final rise for XARG > XF
         DHPOUT = DHFCMP
      END IF

C     Check for stack-tip downwash option
      IF (NOSTD) THEN
         HEOUT = HS + DHPOUT
      ELSE
         HEOUT = HSP + DHPOUT
      END IF

      RETURN
      END

      SUBROUTINE STERAD(HEARG,ZARG,HEOUT)
C***********************************************************************
C                 STERAD Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Adjusts Effective Plume Height for Simple Terrain Effects
C
C        PROGRAMMER: Roger Brode
C
C        DATE:    September 30, 1994
C
C        INPUTS:  HEARG = Flat terrain plume height
C                 ZARG  = Elevation of terrain
C
C        OUTPUTS: HEOUT = Effective plume height with terrain adjustment
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'STERAD'

C     Adjust Plume Height for Elevated Terrain, Save Flat Terrain Value (HEFLAT)
C     For Later Comparison With Mixing Height
      IF (FLAT) THEN
         HEOUT  = HEARG
      ELSE IF (ELEV) THEN
C        Calculate Terrain Hgt Above Plant Grade (Chopped-off at Release Height)
         HTERCHOP = AMIN1( HS, (ZARG - ZS))
         HEOUT = HEARG - HTERCHOP
      END IF

C     Don't Allow Effective Plume Height to be < 0.0
      HEOUT = AMAX1( 0.0, HEOUT)

      RETURN
      END

      SUBROUTINE CTERAD(HEARG,ZARG,HEOUT,COUT)
C***********************************************************************
C                 CTERAD Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Adjusts Effective Plume Height for Complex Terrain Effects
C
C        PROGRAMMER: Roger Brode
C
C        DATE:    September 30, 1994
C
C        INPUTS:  HEARG = Flat terrain plume height
C                 ZARG  = Elevation of terrain
C
C        OUTPUTS: HEOUT = Effective plume height with terrain adjustment
C                 COUT  = Attenuation correction factor
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'CTERAD'

C     Calculate Terrain Hgt Above Plant Grade
      HTER = ZARG - ZS

C     Calculate COMPLEX1 Plume Height
      HEOUT = AMAX1( (HEARG*TCF(KST)),
     &               (HEARG-(1.0-TCF(KST))*HTER) )
      HEOUT = AMAX1( HEOUT, ZMIN )

C     Calculate the Attentuation Correction Factor, COUT
      IF ( (UNSTAB.OR.NEUTRL) .OR. (HEARG.GE.(HTER+ZFLAG)) ) THEN
         COUT = 1.0
      ELSE IF ((HTER+ZFLAG-HEARG) .GE. 400.) THEN
         COUT = 0.0
      ELSE
         COUT = (400. - (HTER+ZFLAG-HEARG))/400.
      END IF

      RETURN
      END

      SUBROUTINE VHEFF(ZARG,HEFOUT,HEOUT)
C***********************************************************************
C                 VHEFF Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Calculates Effective Plume Height for VOLUME Sources (m)
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Arrays of Source Parameters
C                 Logical Wake Flags
C                 Meteorological Variables for One Hour
C                 Wind Speed Adjusted to Stack Height
C                 Downwind Distance
C                 Terrain Elevation of Receptor
C
C        OUTPUTS: Effective Plume Height (HE)
C
C        CALLED FROM:   VCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'VHEFF'

C     Calculate Terrain Height Above Plant Grade (Chopped-off at Release Height)
      IF (FLAT) THEN
         HTERCHOP = 0.0
      ELSE IF (ELEV) THEN
         HTERCHOP = AMIN1( HS, (ZARG - ZS))
      END IF

C     Calculate Effective Plume Height (No Rise) Adjusted for Terrain Height
      HEOUT = HS - HTERCHOP

C     Save Plume Height for Flat Terrain for Later Comparison to Mixing Height
      HEFOUT = HS

      RETURN
      END

      SUBROUTINE PDIS(XARG,SYOUT,SZOUT,XYOUT,XZOUT,SBOUT)
C***********************************************************************
C                 PDIS Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Calculates Dispersion Parameters for POINT Sources
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C        MODIFIED BY D. Strimaitis, SRC (initialize SBID to 0.0)
C
C        DATE:    February 15, 1993
C
C        INPUTS:  Arrays of Source Parameters
C                 Logical Wake Flags
C                 Wake Plume Height, HEMWAK
C                 Meteorological Variables for One Hour
C                 Downwind Distance
C
C        OUTPUTS: Lateral and Vertical Dispersion Coefficients, SY and SZ
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'PDIS'

      IF (.NOT. WAKE) THEN
C        Calculate Sigma-y from Curves                   ---   CALL SIGY
         CALL SIGY(XARG,SYARG)
C        Calculate Sigma-z from Curves                   ---   CALL SIGZ
         CALL SIGZ(XARG,SZARG)
         IF (.NOT. NOBID) THEN
C           Apply BID                                    ---   CALL BID
            CALL BID(DHP,SYARG,SZARG,SYOUT,SZOUT,SBOUT)
         ELSE
            SBOUT = 0.0
            SYOUT = SYARG
            SZOUT = SZARG
         END IF
         XYOUT = 0.0
         XZOUT = 0.0
      ELSE IF (WAKE) THEN
         IF (HEMWAK .GT. 1.2*DSBH) THEN
C           Calculate Sigma-y from Curves                ---   CALL SIGY
            CALL SIGY(XARG,SYARG)
            XYOUT = 0.0
         ELSE
C           Calculate Building Enhanced Sigma-y          ---   CALL SYENH
            CALL SYENH(XARG,SYARG,XYOUT)
         END IF
C        Calculate Building Enhanced Sigma-z             ---   CALL SZENH
         CALL SZENH(XARG,SZARG,XZOUT)
         IF ((.NOT. NOBID) .AND. (.NOT. WAKESS)) THEN
C           Apply BID                                    ---   CALL BID
            CALL BID(DHP,SYARG,SZARG,SYOUT,SZOUT,SBOUT)
         ELSE
            SBOUT = 0.0
            SYOUT = SYARG
            SZOUT = SZARG
         END IF
      END IF

      IF (SZOUT .GT. 5000. .AND. NPD .EQ. 0)  SZOUT = 5000.

      RETURN
      END

      SUBROUTINE PDISC(XARG,SZOUT,XZOUT,SBOUT)
C***********************************************************************
C                 PDISC Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Calculates Dispersion Parameters for POINT Sources
C
C        PROGRAMMER: Roger Brode
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Arrays of Source Parameters
C                 Logical Wake Flags
C                 Wake Plume Height, HEMWAK
C                 Meteorological Variables for One Hour
C                 Downwind Distance
C
C        OUTPUTS: Lateral and Vertical Dispersion Coefficients, SY and SZ
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'PDISC'

C     Calculate Sigma-z from Curves Using Radial Distance   ---   CALL SIGZ
      CALL SIGZ(XARG,SZARG)
      SYARG = 0.0

      IF (.NOT. NOBID) THEN
C        Apply BID                                          ---   CALL BID
         CALL BID(DHPCMP,SYARG,SZARG,SYOUT,SZOUT,SBOUT)
      ELSE
         SBOUT = 0.0
         SZOUT = SZARG
         SYOUT = 0.0
      END IF
      XZOUT = 0.0

      IF (SZOUT .GT. 5000. .AND. NPD .EQ. 0)  SZOUT = 5000.

      RETURN
      END

      SUBROUTINE VDIS(XARG,SYOUT,SZOUT,XYOUT,XZOUT)
C***********************************************************************
C                 VDIS Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Calculates Dispersion Parameters for VOLUME Sources
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Arrays of Source Parameters
C                 Meteorological Variables for One Hour
C                 Downwind Distance
C
C        OUTPUTS: Lateral and Vertical Dispersion Coefficients
C
C        CALLED FROM:   VCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'VDIS'

C     Calculate Lateral Virtual Distance                 ---   CALL XVY
      CALL XVY(XYOUT)
C     Calculate Sigma-y from Curves for X+XY             ---   CALL SIGY
      CALL SIGY(XARG+XYOUT,SYOUT)
C     Calculate Vertical Virtual Distance                ---   CALL XVZ
      CALL XVZ(XARG,XZOUT)
C     Calculate Sigma-z from Curves for X+XZ             ---   CALL SIGZ
      CALL SIGZ(XARG+XZOUT,SZOUT)

      IF (SZOUT .GT. 5000. .AND. NPD .EQ. 0)  SZOUT = 5000.

      RETURN
      END

      SUBROUTINE ADIS(XARG,SYOUT,SZOUT,XYOUT,XZOUT)
C***********************************************************************
C                 ADIS Module of the ISC Short Term Model - Version 2
C
C        PURPOSE: Calculates Dispersion Parameters for AREA Sources
C
C        PROGRAMMER: Roger Brode, PES, Inc.
C
C        DATE:    July 21, 1994
C
C        INPUTS:  Arrays of Source Parameters
C                 Meteorological Variables for One Hour
C                 Downwind Distance
C
C        OUTPUTS: Lateral and Vertical Dispersion Coefficients
C
C        CALLED FROM:   VCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'ADIS'

      X1 = XARG * 0.001
      SZOUT = 1.0
      SYOUT = 1.0
      IF (RURAL .AND. X1 .LE. 0.0005) THEN
         CALL SZCOEF(X1, AFAC, BFAC, X1MAX, X1MIN)
         SZOUT = AFAC
      ELSE
C        Calculate Sigma-y from Curves for X                ---   CALL SIGY
         CALL SIGY(XARG,SYOUT)
C        Calculate Sigma-z from Curves for X                ---   CALL SIGZ
         CALL SIGZ(XARG,SZOUT)
      END IF
      SYOUT = MAX(SYOUT,0.0001)
      SZOUT = MAX(SZOUT,0.0001)
      XYOUT = 0.0
      XZOUT = 0.0

C     Add Initial Dispersion for OPENPIT Sources
      IF (SZINIT .GT. 0.0) THEN
         SZOUT = SQRT (SZOUT*SZOUT + SZINIT*SZINIT)
      END IF

      IF (SZOUT .GT. 5000. .AND. NPD .EQ. 0)  SZOUT = 5000.

      RETURN
      END

      SUBROUTINE PSIMPL
C***********************************************************************
C               PSIMPL Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates Hourly Concentration or Deposition
C                 value for POINT Sources
C                 Using Gaussian Plume Equation for Simple Terrain
C
C                 (Replaces PCHI and PDEP)
C
C           NOTE: Particle settling is treated as a "tilted plume"
C                 until the centerline reaches the surface.  Thereafter
C                 the centroid height of the plume continues to be
C                 modified by gravity.  This process is simulated by
C                 altering the sigma-z for each particle-size.  Hence,
C                 sigma-z is now a function of particle-size.
C
C        PROGRAMMER: D. Strimaitis, SRC
C
C        DATE:    December 15, 1993
C
C        MODIFIED:   To call PDEP for call to SUB. DEPCOR; to use
C                    modified SUB. VERT.  R.W. Brode, PES, Inc. - 9/30/94
C
C        INPUTS:
C
C        OUTPUTS: HRVAL, Concentration or Deposition for Particular
C                 Source/Receptor Combination
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      LOGICAL WDONLY

C     Variable Initializations
      MODNAM = 'PSIMPL'
      WDONLY = .FALSE.

      IF ((UNSTAB .OR. NEUTRL) .AND. HEFLAT.GT.ZI) THEN
C        Plume Is Above Mixing Height, ZI
         IF (DEPOS .OR. WDEP) THEN
C           Set WDONLY flag for Wet Deposition Only
            WDONLY = .TRUE.
         ELSE
            DO ITYP = 1, NUMTYP
               HRVAL(ITYP) = 0.0
            END DO
            GO TO 1000
         END IF
      END IF

      YTERM = -0.5*(Y*Y)/(SY*SY)
      IF (YTERM .GT. EXPLIM) THEN

C        Determine Deposition Correction Factors for Particles
         IF (LDPART .OR. LWPART) THEN
            CALL PDEP (WDONLY)
         ENDIF

         IF (NPD .EQ. 0) THEN
            DO ITYP = 1, NUMTYP
               V(ITYP) = 0.
            END DO
            VSIMP = 0.0
            ITYP = 0
C           Calculate the Vertical Term, V, for gases
            IF (CONC) THEN
               ITYP = ITYP + 1
               IF (WDONLY) THEN
C                 Plume is above mixing height so set CONC = 0.0
                  V(ITYP) = 0.0
               ELSE
C                 Calculate Concentration Form of V         ---   CALL VERT
                  A0 = -0.5/(SZ*SZ)
                  CALL VERT(HE,SZ,A0,ZFLAG,V(ITYP))
               END IF
            ELSE IF (INTERM) THEN
               IF (WDONLY) THEN
C                 Plume is above mixing height so set CONC = 0.0
                  VSIMP = 0.0
               ELSE
C                 Calculate Concentration Form of V         ---   CALL VERT
                  A0 = -0.5/(SZ*SZ)
                  CALL VERT(HE,SZ,A0,ZFLAG,VSIMP)
               END IF
            ENDIF
            IF (DEPOS) THEN
               ITYP = ITYP + 1
C              Calculate Wet Flux Form of V
C              Vertical Term is Integral of EXP terms Over All z
               V(ITYP) = SRT2PI*SZ
C              Apply Scavenging Ratio
               V(ITYP) = V(ITYP) * GSCVRT
            END IF
            IF (DDEP) THEN
               ITYP = ITYP + 1
            END IF
            IF (WDEP) THEN
               ITYP = ITYP + 1
C              Calculate Wet Flux Form of V
C              Vertical Term is Integral of EXP terms Over All z
               V(ITYP) = SRT2PI*SZ
C              Apply Scavenging Ratio
               V(ITYP) = V(ITYP) * GSCVRT
            END IF
C           Allow for Depletion of Gases Due to Wet Scavenging
            IF (LWGAS) THEN
               DO ITYP = 1, NUMTYP
                  V(ITYP) = V(ITYP) * WQCORG
               END DO
               IF (.NOT.CONC .AND. INTERM) THEN
                  VSIMP = VSIMP * WQCORG
               END IF
            END IF

C           Include SZ in the denomenator of V
            DO ITYP = 1, NUMTYP
               V(ITYP) = V(ITYP)/SZ
            END DO
            IF (.NOT.CONC .AND. INTERM) THEN
               VSIMP = VSIMP/SZ
            END IF

         ELSE
C           Calculate the Vertical Term, V for particles
            DO ITYP = 1, NUMTYP
               V(ITYP) = 0.
            END DO
            VSIMP = 0.
            DO J = 1, NPD
               ITYP = 0
C              Settling may alter SZ for the Jth particle plume
               SZADJ = SZ*SZCOR(J)
               A0 = -0.5/(SZADJ*SZADJ)
C              Calculate Plume Tilt Due to Settling, HV
               HV = (X/US) * VGRAV(J)
C              Calculate Settled Plume Height, HESETL
               HESETL = HE - HV
C              Restrict settled height to be positive, so that the plume
C              does not settle below the surface -- this is the limit of
C              the tilted plume technique.
               HESETL = AMAX1(0.0,HESETL)
C              Adjust Jth contribution by mass fraction and source
C              depletion
               ADJ = PHI(J) * DQCOR(J) * WQCOR(J)
               IF (CONC) THEN
C                 Concentration
                  ITYP = ITYP + 1
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set CONC = 0.0
                     V(ITYP) = 0.0
                  ELSE
C                    For Concentration Complete Vertical Term is Needed for
C                    Each Particle Size Calculated at ZFLAG ---   CALL VERT
                     CALL VERT(HESETL,SZADJ,A0,ZFLAG,VJ)
                     V(ITYP) = V(ITYP) + ADJ*PCORZR(J)*VJ/SZADJ
                  END IF
               END IF
               IF (DEPOS .OR. DDEP) THEN
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set DDEP = 0.0
                     DRYFLUX = 0.0
                  ELSE
C                    For Dry Deposition Complete Vertical Term is Needed for
C                    Each Particle Size Calculated at ZRDEP ---   CALL VERT
                     CALL VERT(HESETL,SZADJ,A0,ZRDEP,VJ)
C                    Calculate Dry Flux VJ/SZ
                     DRYFLUX = ADJ*PCORZD(J)*VDEP(J)*VJ/SZADJ
                  END IF
               END IF
               IF (DEPOS .OR. WDEP) THEN
C                 Calculate Wet Flux VJ/SZ --
C                 For Wet Flux, Vertical Term is Integral of EXP terms
C                 Over All z, so VJ/SZ=SQRT(2PI)
                  WETFLUX = ADJ*PSCVRT(J)*SRT2PI
               ENDIF
               IF (DEPOS) THEN
C                 Wet & Dry fluxes of particles are summed
                  ITYP = ITYP + 1
                  V(ITYP) = V(ITYP) + DRYFLUX + WETFLUX
               END IF
               IF (DDEP) THEN
C                 Dry flux of particles
                  ITYP = ITYP + 1
                  V(ITYP) = V(ITYP) + DRYFLUX
               END IF
               IF (WDEP) THEN
C                 Wet flux of particles
                  ITYP = ITYP + 1
                  V(ITYP) = V(ITYP) + WETFLUX
               ENDIF
               IF (.NOT.CONC .AND. INTERM) THEN
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set CONC = 0.0
                     VSIMP = 0.0
                  ELSE
C                    For Concentration Complete Vertical Term is Needed for
C                    Each Particle Size Calculated at ZFLAG ---   CALL VERT
                     CALL VERT(HESETL,SZADJ,A0,ZFLAG,VJ)
C                    Calculate Concentration for Intermediate Terrain Check
                     VSIMP = VSIMP + ADJ*PCORZR(J)*VJ/SZADJ
                  END IF
               END IF
            ENDDO
         END IF

C        Calculate the Decay Term, D                     ---   CALL DECAY
         CALL DECAY (X)

         DO ITYP = 1, NUMTYP
C           Complete VTERM (SZ already in denomenator of V)
            VTERM = (D*V(ITYP))/(TWOPI*US*SY)

C           Check for Possible Underflow Condition
            IF (VTERM.GT.0.0 .AND. (LOG(VTERM)+YTERM).GT.EXPLIM) THEN
               HRVAL(ITYP) = QTK * EMIFAC(ITYP) * VTERM * EXP(YTERM)
            ELSE
               HRVAL(ITYP) = 0.0
            END IF
         END DO

         IF (.NOT.CONC .AND. INTERM) THEN
C           Calculate Concentration for Simple Terrain
C           Complete VTERM (SZ already in denomenator of V)
            VTERM = (D*VSIMP)/(TWOPI*US*SY)

C           Check for Possible Underflow Condition
            IF (VTERM.GT.0.0 .AND. (LOG(VTERM)+YTERM).GT.EXPLIM) THEN
               SIMCON = QTK * EMICON * VTERM * EXP(YTERM)
            ELSE
               SIMCON = 0.0
            END IF
         ELSE IF (CONC .AND. INTERM) THEN
            SIMCON = HRVAL(1)
         END IF

      ELSE
C        Lateral Term is 0.0; Set HRVAL's to 0.0
         DO ITYP = 1, NUMTYP
            HRVAL(ITYP) = 0.0
         END DO
         SIMCON = 0.0
      END IF

 1000 CONTINUE

      IF (DEBUG) THEN
C        Print Out Debugging Information                    ---   CALL DEBOUT
         CALL DEBOUT
      END IF

 999  RETURN
      END

      SUBROUTINE PCOMPL
C***********************************************************************
C               PCOMPL Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates Hourly Concentration or Deposition
C                 value for POINT Sources
C                 Using Gaussian Plume Equation for Complex Terrain
C
C                 (Replaces PCHI and PDEP)
C
C           NOTE: Particle settling is treated as a "tilted plume"
C                 until the centerline reaches the surface.  Thereafter
C                 the centroid height of the plume continues to be
C                 modified by gravity.  This process is simulated by
C                 altering the sigma-z for each particle-size.  Hence,
C                 sigma-z is now a function of particle-size.
C
C        PROGRAMMER: D. Strimaitis, SRC
C
C        DATE:    December 15, 1993
C
C        MODIFIED:   To use fully integrated COMPLEX1 algorithms rather
C                    than calls to CMP1.  R.W. Brode, PES, Inc. - 9/30/94
C
C        INPUTS:
C
C        OUTPUTS: HRVAL, Concentration or Deposition for Particular
C                 Source/Receptor Combination
C
C        CALLED FROM:   PCALC
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      LOGICAL WDONLY

C     Variable Initializations
      MODNAM = 'PCOMPL'
      WDONLY = .FALSE.

      IF ((UNSTAB .OR. NEUTRL) .AND. HECOMP.GT.ZI) THEN
C        Plume Is Above Mixing Height, ZI
         IF (DEPOS .OR. WDEP) THEN
C           Set WDONLY flag for Wet Deposition Only
            WDONLY = .TRUE.
         ELSE
            DO ITYP = 1, NUMTYP
               HRVAL(ITYP) = 0.0
            END DO
            GO TO 1000
         END IF
      END IF

      IF (ABS(Y).LE.X*0.19891 .AND. CORR.GT.0.0) THEN
C        Receptor is inside of sector and Plume is < 400m Below Receptor
         IF (LDPART .OR. LWPART) THEN
            CALL PDEPC (WDONLY)
         ENDIF

         IF (NPD .EQ. 0) THEN
            DO ITYP = 1, NUMTYP
               V(ITYP) = 0.
            END DO
            VCOMP = 0.0
            ITYP = 0
C           Calculate the Vertical Term, V, for gases
            IF (CONC) THEN
               ITYP = ITYP + 1
               IF (WDONLY) THEN
C                 Plume is above mixing height so set CONC = 0.0
                  V(ITYP) = 0.0
               ELSE
C                 Calculate Concentration Form of V         ---   CALL VERT
                  A0 = -0.5/(SZCMP1*SZCMP1)
                  CALL VERT(HECMP1,SZCMP1,A0,ZFLAG,V(ITYP))
               END IF
            ELSE IF (INTERM) THEN
               IF (WDONLY) THEN
C                 Plume is above mixing height so set CONC = 0.0
                  VCOMP = 0.0
               ELSE
C                 Calculate Concentration Form of V         ---   CALL VERT
                  A0 = -0.5/(SZCMP1*SZCMP1)
                  CALL VERT(HECMP1,SZCMP1,A0,ZFLAG,VCOMP)
               END IF
            ENDIF
            IF (DEPOS) THEN
               ITYP = ITYP + 1
C              Calculate Wet Flux Form of V
C              Vertical Term is Integral of EXP terms Over All z
               V(ITYP) = SRT2PI*SZCMP1
C              Apply Scavenging Ratio
               V(ITYP) = V(ITYP) * GSCVRT
            ENDIF
            IF (DDEP) THEN
               ITYP = ITYP + 1
            END IF
            IF (WDEP) THEN
               ITYP = ITYP + 1
C              Calculate Wet Flux Form of V
C              Vertical Term is Integral of EXP terms Over All z
               V(ITYP) = SRT2PI*SZCMP1
C              Apply Scavenging Ratio
               V(ITYP) = V(ITYP) * GSCVRT
            ENDIF
C           Allow for Depletion of Gases Due to Wet Scavenging
            IF (LWGAS) THEN
               DO ITYP = 1, NUMTYP
                  V(ITYP) = V(ITYP) * WQCORGC
               END DO
               IF (.NOT.CONC .AND. INTERM) THEN
                  VCOMP = VCOMP * WQCORG
               END IF
            END IF

C           Apply CORR Attenuation Factor and
C           Include SZ in the denomenator of V
            DO ITYP = 1, NUMTYP
               V(ITYP) = CORR * V(ITYP)/SZCMP1
            END DO
            IF (.NOT.CONC .AND. INTERM) THEN
               VCOMP = CORR * VCOMP/SZCMP1
            END IF

         ELSE
C           Calculate the Vertical Term, V for particles
            DO ITYP = 1, NUMTYP
               V(ITYP) = 0.
            END DO
            VCOMP = 0.
            DO J = 1, NPD
               ITYP = 0
C              Settling may alter SZ for the Jth particle plume
               SZADJ = SZCMP1*SZCORC(J)
               A0 = -0.5/(SZADJ*SZADJ)
C              Calculate Plume Tilt Due to Settling, HV
               HV = (X/US) * VGRAV(J)
C              Calculate Settled Plume Height, HESETL
               HESETL = HECOMP - HV
C              Restrict settled height to be positive, so that the plume
C              does not settle below the surface -- this is the limit of
C              the tilted plume technique.
               HESETL = AMAX1(0.0,HESETL)
C              Calculate Adjusted Plume Height and Attenuation Factor
C              for This Particle Category
               CALL CTERAD(HESETL,ZELEV,HECMP1,CORRJ)
C              Adjust Jth contribution by mass fraction and source
C              depletion
               ADJ = PHI(J) * DQCORC(J) * WQCORC(J)
               IF (CONC) THEN
C                 Concentration
                  ITYP = ITYP + 1
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set CONC = 0.0
                     V(ITYP) = 0.0
                  ELSE
C                    For Concentration, Complete Vertical Term is Needed for
C                    Each Particle Size Calculated at ZFLAG ---   CALL VERT
                     CALL VERT(HECMP1,SZADJ,A0,ZFLAG,VJ)
                     V(ITYP) = V(ITYP) + CORRJ*ADJ*PCORZRC(J)*VJ/SZADJ
                  END IF
               END IF
               IF (DEPOS .OR. DDEP) THEN
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set DRYFLUX = 0.0
                     DRYFLUX = 0.0
                  ELSE
C                    For Dry Deposition, Complete Vertical Term is Needed for
C                    Each Particle Size Calculated at ZRDEP ---   CALL VERT
                     CALL VERT(HECMP1,SZADJ,A0,ZRDEP,VJ)
C                    Calculate Dry Flux VJ/SZ
                     DRYFLUX = CORRJ*ADJ*PCORZDC(J)*VDEP(J)*VJ/SZADJ
                  END IF
               END IF
               IF (DEPOS .OR. WDEP) THEN
C                 Calculate Wet Flux VJ/SZ --
C                 For Wet Flux, Vertical Term is Integral of EXP terms
C                 Over All z, so VJ/SZ=SQRT(2PI)
                  WETFLUX = CORRJ*ADJ*PSCVRT(J)*SRT2PI
               ENDIF
               IF (DEPOS) THEN
C                 Wet & Dry fluxes of particles are summed
                  ITYP = ITYP + 1
                  V(ITYP) = V(ITYP) + DRYFLUX + WETFLUX
               END IF
               IF (DDEP) THEN
C                 Dry flux of particles
                  ITYP = ITYP + 1
                  V(ITYP) = V(ITYP) + DRYFLUX
               END IF
               IF (WDEP) THEN
C                 Wet flux of particles
                  ITYP = ITYP + 1
                  V(ITYP) = V(ITYP) + WETFLUX
               ENDIF
               IF (.NOT.CONC .AND. INTERM) THEN
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set CONC = 0.0
                     VCOMP = 0.0
                  ELSE
C                    For Concentration, Complete Vertical Term is Needed for
C                    Each Particle Size Calculated at ZFLAG ---   CALL VERT
                     CALL VERT(HECMP1,SZADJ,A0,ZFLAG,VJ)
C                    Calculate Concentration for Intermediate Terrain Check
                     VCOMP = VCOMP + CORRJ*ADJ*PCORZRC(J)*VJ/SZADJ
                  END IF
               END IF
            ENDDO
         END IF

C        Calculate the Decay Term, D                        ---   CALL DECAY
         CALL DECAY (X)

         DO ITYP = 1, NUMTYP
C           Calculate HRVAL for Sector Average in Complex Terrain
            HRVAL(ITYP) = (QTK*EMIFAC(ITYP)*D*V(ITYP)) /
     &                    (SRT2PI*DISTR*DELTHP*US)
         END DO

         IF (.NOT.CONC .AND. INTERM) THEN
C           Calculate Concentration for Sector Average in Complex Terrain
            COMCON = (QTK*EMICON*D*VCOMP) /
     &               (SRT2PI*DISTR*DELTHP*US)
         ELSE IF (CONC .AND. INTERM) THEN
            COMCON = HRVAL(1)
         END IF

      ELSE
C        Receptor is outside of sector or Plume is > 400m Below Receptor
         DO ITYP = 1, NUMTYP
            HRVAL(ITYP) = 0.0
         END DO
         COMCON = 0.0
      END IF

 1000 CONTINUE

      IF (DEBUG) THEN
         WCMP1 = DELTHP * DISTR
         WRITE(IOUNIT,*) 'PCOMPL ----------------------------------'
         WRITE(IOUNIT,*) 'Hour, Event        =',IHOUR,IEVENT
         WRITE(IOUNIT,*) '  '
         WRITE(IOUNIT,*) 'QTK, D             =',QTK,D
         WRITE(IOUNIT,*) 'CORRJ, WCMP1, US   =',CORRJ,WCMP1,US
         WRITE(IOUNIT,*) 'PCOMPL ----------------------------------'
      END IF

      IF (DEBUG) THEN
C        Print Out Debugging Information                    ---   CALL DEBOUT
CRWB         CALL DEBOUT
      END IF

      RETURN
      END


      SUBROUTINE ASIMPL(X1,RCZ)
C***********************************************************************
C               ASIMPL Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates Hourly Concentration or Deposition
C                 value for AREA Sources Using Numerical
C                 Integration Algorithm for Simple Terrain
C
C                 (Replaces ACHI and ADEP)
C
C           NOTE: Particle settling is treated as a "tilted plume"
C                 until the centerline reaches the surface.  Thereafter
C                 the centroid height of the plume continues to be
C                 modified by gravity.  This process is simulated by
C                 altering the sigma-z for each particle-size.  Hence,
C                 sigma-z is now a function of particle-size.
C
C        PROGRAMMER: D. Strimaitis, SRC
C
C        DATE:    December 15, 1993
C
C        INPUTS:
C
C        OUTPUTS: Concentration or Deposition for A Unit Of
C                 Source/Receptor Combination
C
C        CALLED FROM:   PLUMEF
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      LOGICAL SCONC, SDEPOS, SDDEP, SWDEP, WDONLY

C     Variable Initializations
      MODNAM = 'ASIMPL'
      WDONLY = .FALSE.

C     Convert distance X1 from km to meters
      XARG = X1 * 1000.

C     Assign output type logicals to local variables
      SCONC  = CONC
      SDEPOS = DEPOS
      SDDEP  = DDEP
      SWDEP  = WDEP
C     Determine appropriate output type for this ITYP, set others to .FALSE.
      IF (ITYP .EQ. 1) THEN
         IF (CONC) THEN
            SDEPOS = .FALSE.
            SDDEP  = .FALSE.
            SWDEP  = .FALSE.
         ELSE IF (DEPOS) THEN
            SCONC  = .FALSE.
            SDDEP  = .FALSE.
            SWDEP  = .FALSE.
         ELSE IF (DDEP) THEN
            SCONC  = .FALSE.
            SDEPOS = .FALSE.
            SWDEP  = .FALSE.
         ELSE IF (WDEP) THEN
            SCONC  = .FALSE.
            SDEPOS = .FALSE.
            SDDEP  = .FALSE.
         END IF
      ELSE IF (ITYP .EQ. 2) THEN
         IF (CONC) THEN
            IF (DEPOS) THEN
               SCONC  = .FALSE.
               SDDEP  = .FALSE.
               SWDEP  = .FALSE.
            ELSE IF (DDEP) THEN
               SCONC  = .FALSE.
               SDEPOS = .FALSE.
               SWDEP  = .FALSE.
            ELSE IF (WDEP) THEN
               SCONC  = .FALSE.
               SDEPOS = .FALSE.
               SDDEP  = .FALSE.
            END IF
         ELSE IF (DEPOS) THEN
            IF (DDEP) THEN
               SCONC  = .FALSE.
               SDEPOS = .FALSE.
               SWDEP  = .FALSE.
            ELSE IF (WDEP) THEN
               SCONC  = .FALSE.
               SDEPOS = .FALSE.
               SDDEP  = .FALSE.
            END IF
         ELSE IF (DDEP) THEN
            IF (WDEP) THEN
               SCONC  = .FALSE.
               SDEPOS = .FALSE.
               SDDEP  = .FALSE.
            END IF
         END IF
      ELSE IF (ITYP .EQ. 3) THEN
         IF (CONC) THEN
            IF (DDEP) THEN
               SCONC  = .FALSE.
               SDEPOS = .FALSE.
               SWDEP  = .FALSE.
            ELSE IF (WDEP) THEN
               SCONC  = .FALSE.
               SDEPOS = .FALSE.
               SDDEP  = .FALSE.
            END IF
         ELSE
            IF (WDEP) THEN
               SCONC  = .FALSE.
               SDEPOS = .FALSE.
               SDDEP  = .FALSE.
            END IF
         END IF
      ELSE IF (ITYP .EQ. 4) THEN
         IF (WDEP) THEN
            SCONC  = .FALSE.
            SDEPOS = .FALSE.
            SDDEP  = .FALSE.
         END IF
      END IF

      IF ((UNSTAB .OR. NEUTRL) .AND. HEFLAT.GT.ZI) THEN
C        Plume is above mixing height, ZI
         IF (DEPOS .OR. WDEP) THEN
C           Set WDONLY flag for Wet Deposition Only
            WDONLY = .TRUE.
         ELSE
            V(ITYP) = 0.0
            RCZ     = 0.0
            GO TO 1000
         END IF
      END IF

      RCZ = 0.0
      IF (XARG .GE. 1.0) THEN
         IF (NPD .EQ. 0) THEN
            V(ITYP) = 0.
C           Calculate the Vertical Term, V, for gases
            IF (SCONC) THEN
               IF (WDONLY) THEN
C                 Plume is above mixing height so set CONC = 0.0
                  V(ITYP) = 0.0
               ELSE
C                 Calculate Concentration Form of V         ---   CALL VERT
                  A0 = -0.5/(SZ*SZ)
                  CALL VERT(HE,SZ,A0,ZFLAG,V(ITYP))
               END IF
            ELSE IF (SDEPOS .OR. SWDEP) THEN
C              Calculate Wet Flux Form of V
C              Vertical Term is Integral of EXP terms Over All z
               V(ITYP) = SRT2PI*SZ
C              Apply Scavenging Ratio
               V(ITYP) = V(ITYP) * GSCVRT
            ENDIF
C           Allow for Depletion of Gases Due to Wet Scavenging
            IF (LWGAS) THEN
               V(ITYP) = V(ITYP) * WQCORG
            END IF

C           Include SZ in the denomenator of V
            V(ITYP) = V(ITYP)/SZ

         ELSE
C           Calculate the Vertical Term, V for particles
            V(ITYP) = 0.0
            DO J = 1, NPD
C              Settling may alter SZ for the Jth particle plume
               SZADJ = SZ*SZCOR(J)
               A0 = -0.5/(SZADJ*SZADJ)
C              Calculate Plume Tilt Due to Settling, HV
               HV = (XARG/US) * VGRAV(J)
C              Calculate Settled Plume Height, HESETL
               HESETL = HE - HV
C              Restrict settled height to be positive, so that the plume
C              does not settle below the surface -- this is the limit of
C              the tilted plume technique.
               HESETL = AMAX1(0.0,HESETL)
C              Adjust Jth contribution by mass fraction and source
C              depletion
               ADJ = PHI(J) * DQCOR(J) * WQCOR(J)
               IF (SCONC) THEN
C                 Concentration
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set CONC = 0.0
                     V(ITYP) = 0.0
                  ELSE
C                    For Concentration, Complete Vertical Term is Needed for
C                    Each Particle Size Calulated at ZFLAG     ---   CALL VERT
                     CALL VERT(HESETL,SZADJ,A0,ZFLAG,VJ)
                     V(ITYP) = V(ITYP) + ADJ*PCORZR(J)*VJ/SZADJ
                  END IF
               ELSE IF (SDEPOS) THEN
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set DRYFLUX = 0.0
                     DRYFLUX = 0.0
                  ELSE
C                    For Dry Deposition, Complete Vertical Term is Needed for
C                    Each Particle Size Calulated at ZRDEP     ---   CALL VERT
                     CALL VERT(HESETL,SZADJ,A0,ZRDEP,VJ)
C                    Calculate Dry Flux VJ/SZ
                     DRYFLUX = ADJ*PCORZD(J)*VDEP(J)*VJ/SZADJ
                  END IF
C                 Calculate Wet Flux VJ/SZ --
C                 For Wet Flux, Vertical Term is Integral of EXP terms
C                 Over All z, so VJ/SZ=SQRT(2PI)
                  WETFLUX = ADJ*PSCVRT(J)*SRT2PI
C                 Wet & Dry fluxes of particles are summed
                  V(ITYP) = V(ITYP) + DRYFLUX + WETFLUX
               ELSE IF (SDDEP) THEN
                  IF (WDONLY) THEN
C                    Plume is above mixing height so set DDEP = 0.0
                     V(ITYP) = 0.0
                  ELSE
C                    For Dry Deposition, Complete Vertical Term is Needed for
C                    Each Particle Size Calulated at ZRDEP     ---   CALL VERT
                     CALL VERT(HESETL,SZADJ,A0,ZRDEP,VJ)
C                    Calculate Dry Flux VJ/SZ
                     DRYFLUX = ADJ*PCORZD(J)*VDEP(J)*VJ/SZADJ
C                    Dry flux of particles
                     V(ITYP) = V(ITYP) + DRYFLUX
                  END IF
               ELSE IF (SWDEP) THEN
C                 Calculate Wet Flux VJ/SZ --
C                 For Wet Flux, Vertical Term is Integral of EXP terms
C                 Over All z, so VJ/SZ=SQRT(2PI)
                  WETFLUX = ADJ*PSCVRT(J)*SRT2PI
C                 Wet flux of particles
                  V(ITYP) = V(ITYP) + WETFLUX
               ENDIF
            ENDDO
         END IF

C        Calculate the Decay Term, D                        ---   CALL DECAY
         CALL DECAY (XARG)

C        Complete TERM (SZ already in denomenator of V)
         RCZ = (D*V(ITYP))/(SRT2PI)

      END IF

 1000 CONTINUE

      RETURN
      END


      SUBROUTINE DEBOUT
C***********************************************************************
C                 DEBOUT Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Outputs Debugging Information: Sigmas, Plume Heights,
C                 etc., for Each Calculation
C
C        PROGRAMMER: Roger Brode, Jeff Wang
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Downwind Distance
C                 Crosswind Distance
C                 Plume Height
C                 Stack Top Wind Speed
C                 Lateral Dispersion Parameter
C                 Vertical Dispersion Parameter
C                 Stability Class
C                 Mixing Height
C                 Receptor Height Above Ground
C                 Emission Rate and Units Scaling Factor
C                 Source Parameter Arrays
C
C        OUTPUTS: Debug Outputs
C
C        CALLED FROM:   PSIMPL, AREAIN
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'DEBOUT'

      WRITE(IOUNIT,119) JDAY, IHOUR, KURDAT, ISRC, IEVENT
 119  FORMAT(/1X,'JDAY= ',I3,'  IHOUR= ',I5,'  KURDAT= ',I10,
     &       '  ISRC= ',I3,'  IEVENT= ',I5)

      IF (SRCTYP(ISRC) .EQ. 'POINT') THEN
         WRITE(IOUNIT,209) QS, HS, TS, VS, DS, DSBH, DSBW, US
 209     FORMAT(1X,'QS= ',F8.2,' HS= ',F8.2,' TS= ',F8.2,' VS= ',
     &       F8.2,' DS= ',F8.2,' DSBH= ',F8.2,' DSBW= ',F8.2,
     &       ' US= ',F8.5)
         WRITE(IOUNIT,219) FB, FM
 219     FORMAT(1X,' FB= ',F11.5,' FM= ',F11.5)
      ELSE IF (SRCTYP(ISRC) .EQ. 'VOLUME') THEN
         WRITE(IOUNIT,229) QS, HS, SYINIT, SZINIT, US
 229     FORMAT(1X,'QS= ',F8.2,'  HS= ',F8.2,'  SYINIT= ',F8.2,
     &          '  SZINIT= ',F8.2,'  US= ',F8.5)
      ELSE IF (SRCTYP(ISRC) .EQ. 'AREA') THEN

         WRITE(IOUNIT,239) QS, HS, XINIT, US, E, SZINIT
 239     FORMAT(1X,'QS= ',F8.2,'  HS= ',F8.2,'  XINIT= ',F8.2,
     &          '  US= ',F8.5,'  E= ',G14.8,
     &          '  SZINIT= ',F8.2)

      END IF

      WRITE(IOUNIT,319) X, Y, XY, XZ, SY, SZ
 319  FORMAT(1X,'X= ',F12.4,'  Y= ',F12.4,'  XY= ',F11.5,'  XZ= ',
     &       F11.5,'  SY= ',F11.5,'  SZ= ',F12.5)
      IF (CONC) THEN
         WRITE(IOUNIT,409) HE, HEMWAK, HEFLAT, KST, TA, ZI, V(ITYP), D
 409     FORMAT(1X,'HE= ',F11.5,'  HEMWAK= ',F11.5,'  HEFLAT= ',F11.5,
     &       '  KST= ',I2,'  TA= ',F6.1,'  ZI= ',F8.2,'  V= ',E12.6,
     &       '  D= ',E12.6)
      ELSE
         WRITE(IOUNIT,419) HE, HEMWAK, HEFLAT, KST, TA, ZI, V(ITYP), D
 419     FORMAT(1X,'HE= ',F11.5,'  HEMWAK= ',F11.5,'  HEFLAT= ',F11.5,
     &       '  KST= ',I2,'  TA= ',F6.1,'  ZI= ',F8.2,'  V= ',E12.6,
     &       '  D= ',E12.6)
      END IF
      WRITE(IOUNIT,519) ZLB, RINIT, ZLY, DA, WAKE, WAKESS
 519  FORMAT(1X,'ZLB=',F11.5,'  RINIT= ',F9.4,'  ZLY= ',
     &       F9.4,'  DA= ',F8.6,'  WAKE= ',L3,'  WAKESS=',L3)
      WRITE(IOUNIT,619) QTK, XF, XFB, XFM, DHF, DHP
 619  FORMAT(1X,'QTK= ',E12.5,'  XF= ',F9.2,
     &       '  XFB= ',F9.2,'  XFM= ',F9.2,'  DHF= ',F9.2,
     &       '  DHP= ',F9.2)

      WRITE(IOUNIT,719) HRVAL(ITYP)
 719  FORMAT(1X,'*** HRVAL= ',G16.8,' ***')

      RETURN
      END

c----------------------------------------------------------------------
      subroutine vdp
c----------------------------------------------------------------------
c
c --- ISC2ST     Version:  1.0     Level:  930215                   VDP
c                J. Scire, SRC
c
c --- MODIFIED   May 26, 1995
c                Modified atmospheric resistance term, ra, based on
c                D. Byun and R. Dennis, Atmos. Environ., Vol. 29, No. 1
c                R. W. Brode, PES, Inc.
c
c --- MODIFIED   March 9, 1994
c                Changed procedure for estimating the deposition layer
c                resistance.
c                D.T. Bailey, USEPA
c
c --- PURPOSE:  Compute particle deposition velocities for each size
c               category of a size distribution.
c
c --- INPUTS:
c     Common block /METVAR/ variables:
c               Z0M - real       - Surface roughness length (m)
c             USTAR - real       - Friction velocity (m/s)
c                EL - real       - Monin-Obukhov length (m)
c     Common block /CALCS3/ variables:
c               NPD - integer    - Number of particle size categories
c             PDIAM - real array - Mean diameter (microns) of each
c                                  particle size category
c               PHI - real array - Mass fraction in each size category
c             PDENS - real       - Particle density (g/cm**3)
c                SC - real array - Schmidt number
c             VGRAV - real array - Gravitational settling velocity (m/s)
c             TSTOP - real array - Stopping time (s)
c     Common block /SOURC4/ variables:
c            VAIRMS - real       - Viscosity of air (m**2/s)
c             ZRDEP - real       - Reference height (m)
c            VDPHOR - real       - Phoretic effects term (m/s)
c
c --- OUTPUT:
c     Common block /CALCS3/ variables:
c              VDEP - real array - Deposition velocity (m/s) for each
c                                  particle size category
c
c --- VDP called by:  PCALC, VCALC, ACALC
c --- VDP calls:      none
c----------------------------------------------------------------------
c
      INCLUDE 'EVMAIN1.INC'
c
      real rd(npdmax)
c
      io6=iounit

C     Calculate Deposition Reference Height, ZRDEP.
      ZRDEP = AMAX1( 1.0, 20.*Z0M)
c
c ***
      if(DEBUG)then
         write(io6,*)
         write(io6,*)'SUBR. VDP -- Inputs'
         write(io6,*)'USTAR (m/s)     = ',ustar
         write(io6,*)'MONIN-EL (m)    = ',el
         write(io6,*)'Z0M (m)         = ',z0m
         write(io6,*)'VDPHOR (m/s)    = ',vdphor
         write(io6,*)'NPD             = ',npd
         write(io6,*)'PDIAM (um)      = ',(pdiam(n),n=1,npd)
         write(io6,*)'FRACT           = ',(phi(n),n=1,npd)
         write(io6,*)'PDENS (g/cm**3) = ',(pdens(n),n=1,npd)
         write(io6,*)'SC              = ',(sc(n),n=1,npd)
         write(io6,*)'VGRAV (m/s)     = ',(vgrav(n),n=1,npd)
         write(io6,*)'TSTOP (s)       = ',(tstop(n),n=1,npd)
         write(io6,*)'VAIRMS (m**2/s) = ',vairms
         write(io6,*)'ZRDEP (m)       = ',zrdep
         write(io6,*)'VDPHOR (m/s)    = ',vdphor
      endif
c ***
c
c --- Use minimum value of USTAR to avoid numerical problems
c --- when USTAR near zero
      ustarr=AMAX1(ustar,1.e-9)
c
c --- Minimum absolute value of Monin-Obukhov length is 1.0 m
      if(el.GE.0.0)then
c ---    stable
         ell=AMAX1(el,1.0)
      else
c ---    unstable
         ell=AMIN1(el,-1.0)
      endif
c
c --- Calculate atmospheric resistance (s/m)
      elabs=ABS(ell)
      if (ell .gt. 0.0) then
c ---    Stable
c ---    VK is the von Karman constant, set as parameter in EVMAIN1.INC
         psih = 4.7*zrdep/ell
         ra = (1.0/(vk*ustarr)) * (ALOG(zrdep/z0m) + psih)

      else
c ---    Unstable
         a1 = 16.*zrdep/elabs
         b1 = 16.*z0m/elabs
         ra = (1.0/(vk*ustarr)) * (1.0*ALOG(
     &        ((2.+a1)-2.*SQRT(1.+a1)) * ((2.+b1)+2.*SQRT(1.+b1)) /
     &        (a1*b1) ))
      endif
c
      t1=ustarr*ustarr/vairms
c
c ***
      if(DEBUG)then
         write(io6,*)
         write(io6,*)'USTARR (m/s)    = ',ustarr
         write(io6,*)'ELL (m)         = ',ell
         write(io6,*)'PSIH            = ',psih
      endif
c ***
c
c --- LOOP OVER SIZE INTERVALS
      do 10 i=1,npd
c
         st=tstop(i)*t1
c
c ---    Compute inertial impaction term
         xinert=10**(-3./st)
c
c ---    Adjust (raise) the Schmidt Number to the 2/3rd's power.
         Schmidt = sc(i) ** (-.667)                                       DTB94068
c
c ---    Compute the deposition layer resistance (s/m)
         rd(i)=1.0 / (ustarr * (Schmidt + xinert))                        DTB94068
c
c ---    Deposition velocity for this current interval
         vdep(i)=1.0/(ra+rd(i)+ra*rd(i)*vgrav(i))+vgrav(i)+vdphor
10    continue
c ***
      if(DEBUG)then
         write(io6,*)
         write(io6,*)'RA (s/m)    = ',ra
         write(io6,*)'RD (s/m)    = ',(rd(n),n=1,npd)
         write(io6,*)'VDEP (m/s)  = ',(vdep(n),n=1,npd)
      endif
c ***
c
      return
      end

c-----------------------------------------------------------------------
      subroutine setszmn
c-----------------------------------------------------------------------
c
c --- ISCST2    Version: 1.0            Level: 931215           SETSZMN
c               D. Strimaitis, SRC
c
c PURPOSE:     SETSZMN determines the value of sigma-z at which the rate
c              of growth in sigma-z equals the rate at which the settling
c              velocity acts to reduce the height of the center-of-mass.
c              A default minimum of 2*zd, where zd is the near-surface
c              height at which the deposition flux is evaluated, is
c              returned if there is no balance-point.
c
c ARGUMENTS:  (EVMAIN1.INC)
c    PASSED:  kst       stability class (A=1, F=6)                   [i]
c             zrdep     reference height for deposition flux  (m)    [r]
c             vs        settling velocity  (m/s)                     [r]
c             us        plume advection wind speed (m/s)             [r]
c             urban     logical for URBAN/RURAL dispersion params    [l]
c             npd       number of particle size categories           [i]
c
c  RETURNED:  szmin     Minimum value of sigma-z (m)                 [r]
c
c CALLING ROUTINES:   PCALC, VCALC, ACALC
c
c EXTERNAL ROUTINES:  GCUBIC
c-----------------------------------------------------------------------
      include 'EVMAIN1.INC'

      real root(3),car(6),cau(6),cbr(6),cbu(6)

      data car/.2,.12,.08,.06,.03,.016/
      data cbr/0.,0.,.0002,.0015,.0003,.0003/
      data cau/.24,.24,.2,.14,.08,.08/
      data cbu/.001,.001,0.,.0003,.0015,.0015/


c --- Loop over particle sizes
      do i=1,npd
         xmin=0.0
         szmin(i)=2.*zrdep
         c=rtpiby2*vgrav(i)/us

c ---    Urban section
         if(URBAN) then
            a=cau(kst)
            b=cbu(kst)
            if(kst .GE. 4) then
               if(a .GT. 20.*c) then
                  szmin(i)=a*a/(2.*b*c)
               elseif(a .GT. c) then
c ---             Solve cubic for y=bx, then report x      ---  call GCUBIC
                  aby2csq=(a/(2.*c))**2
                  a1=(3.-aby2csq)
                  a2=(3.-4.*aby2csq)
                  a3=(1.-4.*aby2csq)
                  call GCUBIC(a1,a2,a3,root)
c ---             There should be ONE real root
                  if(root(2) .NE. 0. .OR. root(3) .NE. 0.) then
                     write(*,*) 'SETSZMN: Potential error!!! '
                     write(*,*) 'More than 1 root ----'
                     write(*,*) 'xb= ',(root(j),j=1,3)
                  endif
                  xmin=root(1)/b
                  szmin(i)=a*xmin/SQRT(1.+b*xmin)
               endif
            endif

c ---    Rural section
         else
            a=car(kst)
            b=cbr(kst)
            if(kst .EQ. 3 .OR. kst .EQ. 4) then
               if(a .GT. 20.*c) then
                  szmin(i)=a*a/(2.*b*c)
               elseif(a .GT. c) then
c ---             Solve cubic for y=bx, then report x      ---  call GCUBIC
                  aby2csq=(a/(2.*c))**2
                  a1=(3.-aby2csq)
                  a2=(3.-4.*aby2csq)
                  a3=(1.-4.*aby2csq)
                  call GCUBIC(a1,a2,a3,root)
c ---             There should be ONE real root
                  if(root(2) .NE. 0. .OR. root(3) .NE. 0.) then
                     write(*,*) 'Potential error!!! More than 1 root'
                     write(*,*) 'xb= ',(root(j),j=1,3)
                  endif
                  xmin=root(1)/b
                  szmin(i)=a*xmin/SQRT(1.+b*xmin)
               endif
            elseif(kst .GT. 4) then
               if(a .GT. c) then
                  xmin=(SQRT(a/c)-1.)/b
                  szmin(i)=a*xmin/(1+b*xmin)
               endif
            endif
         endif

      enddo

      return
      end

c-----------------------------------------------------------------------
      subroutine gcubic(a1,a2,a3,root)
c-----------------------------------------------------------------------
c
c --- ISCST2    Version: 1.0            Level: 931215           GCUBIC
c               D. Strimaitis, SRC
c
c PURPOSE:     Program solves the general cubic equation of the form:
c                  0 = x**3 + (a1)x**2 + (a2)x + (a3)
c              for the real roots
c              (Numerical Recipes, Press et al., 1986)
c
c ARGUMENTS:
c    PASSED:  a1,a2,a3  constants for terms as described above       [r]
c
c  RETURNED:  root      root(s) of equation                          [r]
c
c CALLING ROUTINES:   (utility routine)
c
c EXTERNAL ROUTINES:  none
c-----------------------------------------------------------------------

      real root(3)

      data twopi/6.2831853/,fourpi/12.566371/

      third=1./3.
      a1sq=a1*a1
      a1cube=a1*a1sq
      a1by3=a1*third

      q=(a1sq-3.*a2)/9.
      r=(2.*a1cube-9.*a1*a2+27.*a3)/54.

      qcube=q*q*q
      rsq=r*r

      if(qcube .GE. rsq) then
c ---    THREE real roots
         sqrtq2=SQRT(q)*2.
         theta=ACOS(r/SQRT(qcube))
         root(1)=-sqrtq2*COS(theta/3.)-a1by3
         root(2)=-sqrtq2*COS((theta+twopi)/3.)-a1by3
         root(3)=-sqrtq2*COS((theta+fourpi)/3.)-a1by3
      else
c ---    ONE real root
         arg=(SQRT(rsq-qcube)+ABS(r))**third
         root(1)=-SIGN(1.0,r)*(arg+q/arg)-a1by3
         root(2)=0.
         root(3)=0.
      endif


      return
      end

c----------------------------------------------------------------------
      subroutine scavrat
c----------------------------------------------------------------------
c
c --- ISCST2     Version: 1.0       Level: 931108               SCAVRAT
c                D. Strimaitis, SRC
c
c --- PURPOSE:  Compute the wet SCAVenging RATio for particles, as a
c               function of particle size, and for gases
c
c --- INPUTS:
c     Common block /METVAR/ variables:
c            IPCODE - integer    - Precip. code (00-45)
c             PRATE - real       - Precip. rate (mm/hr)
c                TA - real       - Ambient Temperature (deg K)
c     Common block /CALCS3/ variables:
c               NPD - integer    - Number of particle size categories
c             PSCAV - real array - Particle scavenging coefs. for liquid
c                                  (1) and frozen (2) precip. for each
c                                  size category (1/[s-mm/hr])
c             GSCAV - real array - Gas scavenging coefs. for liquid (1)
c                                  and frozen (2) precip. (1/[s-mm/hr])
c
c --- OUTPUT:
c     Common block /CALCS3/ variables:
c            PSCVRT - real array - Scavenging ratio for particles (1/s)
c            GSCVRT - real       - Scavenging ratio for gases (1/s)
c
c --- SCAVRAT called by:  PCALC, VCALC, ACALC
c --- SCAVRAT calls:      none
c----------------------------------------------------------------------
c
c --- Include common blocks
      include 'EVMAIN1.INC'

      data imiss/9999/

      if(DEBUG)then
         write(iounit,*)
         write(iounit,*)'SUBR. SCAVRAT -- Inputs'
         write(iounit,*)'IPCODE               = ',ipcode
         write(iounit,*)'PRATE (mm/hr)        = ',prate
         write(iounit,*)'TA (deg K)           = ',ta
         write(iounit,*)'NPD                  = ',npd
         write(iounit,*)'PSCAV(1) 1/(s-mm/hr) = ',(pscav(n,1),n=1,npd)
         write(iounit,*)'PSCAV(2) 1/(s-mm/hr) = ',(pscav(n,2),n=1,npd)
         write(iounit,*)'GSCAV(1) 1/(s-mm/hr) = ',gscav(1)
         write(iounit,*)'GSCAV(2) 1/(s-mm/hr) = ',gscav(2)
         write(iounit,*)' (1 = Liquid ; 2 = Frozen )'
         write(iounit,*)
      endif

c --- If no precipitation, no wet removal
      if(prate .EQ. 0.) then
         do i=1,npd
            pscvrt(i)=0.0
         enddo
         gscvrt=0.0
      else
c ---    Determine if precip. is liquid (ILQ=1) or frozen (ILQ=2)
         if(ipcode .EQ. imiss .OR. ipcode .EQ. 0) then
c ---       Precip. code is unavailable due to missing data or no
c           precip. at time of obs. at surface station, therefore,
c           determine precip. type based on the air temperature
c ---       Assume liquid precip. if temp. > freezing, otherwise,
c           assume frozen precip.
            if(ta .GT. 273.15) then
               ilq=1
            else
               ilq=2
            endif
         else if(ipcode .LE. 18) then
c ---       Liquid precipitation type
            ilq=1
         else
c ---       Frozen precipitation type
            ilq=2
         endif
c ---    Determine the scavenging ratios
         do i=1,npd
            pscvrt(i)=pscav(i,ilq)*prate
         enddo
         gscvrt=gscav(ilq)*prate
      endif

      if(DEBUG)then
         write(iounit,*)'SUBR. SCAVRAT -- Results'
         write(iounit,*)'GSCVRT (1/s)= ',gscvrt
         write(iounit,*)'PSCVRT (1/s)= ',(pscvrt(n),n=1,npd)
         write(iounit,*)
      endif

      return
      end


      SUBROUTINE PDEP (LWDONLY)
C***********************************************************************
C               PDEP Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates Simple Terrain Deposition Adjustment
C                 Factors from DEPCOR
C
C        PROGRAMMER: R. W. Brode, PES, Inc.
C
C        DATE:    September 30, 1994
C
C        MODIFIED:   To add logical argument for Wet Deposition Only,
C                    to skip call to DEPCOR when plume is above ZI.
C                    R.W. Brode, PES, 7/17/95
C
C        INPUTS:     LWDONLY, logical specifying whether Wet Deposition
C                    Only is to be calculated for plume above ZI
C
C        OUTPUTS:
C
C
C        CALLED FROM:   PSIMPL
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      LOGICAL LTERR, LWDONLY

C     Variable Initializations
      MODNAM = 'PDEP'

C     Set LTERR to FALSE to signal simple terrain call to DEPCOR.
      LTERR = .FALSE.

C     Loop over particle sizes
      DO 150 I=1,NPD
         DQCOR(I)  = 1.0
         PCORZR(I) = 1.0
         PCORZD(I) = 1.0
         SZCOR(I)  = 1.0
C        Initialize wet & dry source depletion factors,
C        profile correction factors, and settles sigma-z
C        factors to unity. - Done in DEPCOR
         IF (DDPLETE .AND. .NOT.LWDONLY) THEN
C           Determine factors for depletion - note that
C           plume ht adjustment for terrain is signalled
C           by a local logical - LTERR
C           Simple Terrain Model          ---   CALL DEPCOR
            CALL DEPCOR( VDEP(I),VGRAV(I),ZRDEP,ZFLAG,
     &        X,XZ,HEFLAT,ZI,US,XS,YS,XR,YR,
     &        RURAL,URBAN,KST,SZ,SBID,
     &        SZMIN(I),ZELEV,ZS,LTERR,DEBUG,IOUNIT,
     &        SRCTYP(ISRC),LTGRID,KURDAT,
     &        DQCOR(I),PCORZR(I),PCORZD(I),SZCOR(I))
         END IF
         IF (WDPLETE) THEN
C           Determine source depletion factor
C           from wet removal
C           Simple Terrain Model
            WQCOR(I) = EXP(-PSCVRT(I)*X/US)
         ELSE
            WQCOR(I) = 1.
         ENDIF
150   CONTINUE

      RETURN
      END


      SUBROUTINE PDEPC (LWDONLY)
C***********************************************************************
C               PDEPC Module of ISC2 Short Term Model - ISCST2
C
C        PURPOSE: Calculates Complex Terrain Deposition Adjustment
C                 Factors from DEPCOR
C
C        PROGRAMMER: R. W. Brode, PES, Inc.
C
C        DATE:    September 30, 1994
C
C        MODIFIED:   To add logical argument for Wet Deposition Only,
C                    to skip call to DEPCOR when plume is above ZI.
C                    R.W. Brode, PES, 7/17/95
C
C        INPUTS:     LWDONLY, logical specifying whether Wet Deposition
C                    Only is to be calculated for plume above ZI
C
C        OUTPUTS:
C
C
C        CALLED FROM:   PCOMPL
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      LOGICAL LTERR, LWDONLY

C     Variable Initializations
      MODNAM = 'PDEPC'

C     Set LTERR to TRUE to signal complex terrain call to DEPCOR.
      LTERR = .TRUE.

C     Loop over particle sizes
      DO 150 I=1,NPD
         DQCORC(I)  = 1.0
         PCORZRC(I) = 1.0
         PCORZDC(I) = 1.0
         SZCORC(I)  = 1.0
C        Initialize wet & dry source depletion factors,
C        profile correction factors, and settles sigma-z
C        factors to unity. - Done in DEPCOR
         IF (DDPLETE .AND. .NOT.LWDONLY) THEN
C           Determine factors for depletion - note that
C           plume ht adjustment for terrain is signalled
C           by a local logical - LTERR
C           Complex Terrain Model         ---   CALL DEPCOR
            CALL DEPCOR( VDEP(I),VGRAV(I),ZRDEP,ZFLAG,
     &        DISTR,XZCMP1,HECOMP,ZI,US,XS,YS,XR,YR,
     &        RURAL,URBAN,KST,SZCMP1,SBCMP1,
     &        SZMIN(I),ZELEV,ZS,LTERR,DEBUG,IOUNIT,
     &        SRCTYP(ISRC),LTGRID,KURDAT,
     &        DQCORC(I),PCORZRC(I),PCORZDC(I),
     &        SZCORC(I))
         END IF
         IF (WDPLETE) THEN
C           Determine source depletion factor
C           from wet removal
C           Complex Terrain Model - use radial distance
            WQCORC(I) = EXP(-PSCVRT(I)*DISTR/US)
         ELSE
            WQCORC(I) = 1.
         ENDIF
150   CONTINUE

      RETURN
      END
