      SUBROUTINE AVEREV
C***********************************************************************
C                 AVEREV Module of ISC2 Model - EVENT
C
C        PURPOSE: Sums Values and Calculates Averages
C
C        PROGRAMMER: Jeff Wang, Roger Brode
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Averaging Time Option Switches
C                 Array of CONC or DEPOS Values for One Hour, HRVALS
C
C        OUTPUTS: Updated Array of Cumulative Values and Averages, AVEVAL
C
C        CALLED FROM:   EVLOOP
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'AVEREV'

C     Calculate Average CONCentrations If Hour is Right
      IF (CONC) THEN
         IF (EVAPER(IEVENT) .NE. 1) THEN
C           Calculate Denominator Considering Calms and Missing,
C           Skipping Averaging if Averaging Period is 1-Hour
            SNUM = AMAX0((NUMHRS-NUMCLM-NUMMSG),
     &                    NINT(NUMHRS*0.75+0.4))
C           Begin Source Group LOOP
            DO 700 ISRC = 1, NUMSRC
               IF (IGROUP(ISRC,IDXEV(IEVENT)) .EQ. 1) THEN
                  AVEVAL(ISRC) = (1./SNUM) * AVEVAL(ISRC)
               ENDIF
 700        CONTINUE
C           End Source Group LOOP
         END IF
      END IF

C     Calculate The Group Value
      GRPAVE = 0.
C     Begin Source Group LOOP
      DO 800 ISRC = 1, NUMSRC
         IF (IGROUP(ISRC,IDXEV(IEVENT)) .EQ. 1) THEN
            GRPAVE = GRPAVE + AVEVAL(ISRC)
         ENDIF
 800  CONTINUE
C     End Source Group LOOP

      RETURN
      END

      SUBROUTINE OUTPUT
C***********************************************************************
C                 OUTPUT Module of ISC2 Model - EVENT
C
C        PURPOSE: Controls Output of Printed Model Results
C
C        PROGRAMMER: Jeff Wang, Roger Brode
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Arrays of Source Parameters
C                 Arrays of Receptor Locations
C                 Arrays of Model Results
C
C        OUTPUTS: Printed Model Outputs
C
C        CALLED FROM:   MAIN
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'OUTPUT'

      IF (SOCONT) THEN
C        Print Out Source Contribution To the Event         ---   CALL PRTSOC
         CALL PRTSOC
      ELSE IF (DETAIL) THEN
C        Print Out Detal Summary of The Event               ---   CALL PRTDET
         CALL PRTDET
      END IF

      RETURN
      END

      SUBROUTINE PRTSOC
C***********************************************************************
C                 PRTSOC Module of ISC2 Model - EVENT
C
C        PURPOSE: Print Out The Source Contribution Data
C                 To The Event
C
C        PROGRAMMER: Jeff Wang, Roger Brode
C
C        DATE:    March 2, 1992
C
C        MODIFIED:   To correct overflow on format statement 9068, and
C                    to use separate array for source IDs in the header
C                    (HEADID) - 9/29/92
C
C        INPUTS:  Arrays of Source Parameters
C                 Arrays of Model Results
C
C        OUTPUTS: Printed Model Outputs
C
C        CALLED FROM:   OUTPUT
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      DIMENSION WAVEV(NSRC)
      CHARACTER*8 HEADID(NSRC)

C     Variable Initializations
      MODNAM = 'PRTSOC'

C     Set Up The Print Array
      INGRP = 0
      DO 210 ISRC = 1, NUMSRC
         IF (IGROUP(ISRC,IDXEV(IEVENT)) .EQ. 1) THEN
            INGRP = INGRP + 1
            WORKID(INGRP) = SRCID(ISRC)
            HEADID(INGRP) = SRCID(ISRC)
            WAVEV(INGRP)  = AVEVAL(ISRC)
         END IF
 210  CONTINUE
C     Check for More Than 34 Sources Per Group
      IF (INGRP .GT. 34) THEN
         HEADID(34) = ' . . . '
         IOGRP = 34
      ELSE
         IOGRP = INGRP
      END IF

C     Determine Number of Rows, NROW, @ 3 Values Per Row
      NROW = 1 + INT((INGRP-1)/3)
C     Determine Number of Pages, NPAGE, @ 40 Rows Per Page
      NPAGE = 1 + INT((NROW-1)/40)

C     Loop Through Pages For This Event
      DO 500 N = 1, NPAGE

C        Print The Source Contributions
         CALL HEADER
         WRITE(IOUNIT,9058) EVNAME(IEVENT), EVAPER(IEVENT),
     &             EVDATE(IEVENT), AXR(IEVENT), AYR(IEVENT),
     &             AZELEV(IEVENT), AZFLAG(IEVENT)

         WRITE(IOUNIT,9068) EVGRP(IEVENT), (HEADID(I),I=1,IOGRP)
         WRITE(IOUNIT,9070) GRPAVE
         WRITE(IOUNIT,9062)

C        Print Out The Source Contributions
         IF (N .EQ. NPAGE) THEN
            WRITE(IOUNIT,9066) (WORKID(I), WAVEV(I),I=1+120*(N-1),INGRP)
         ELSE
            WRITE(IOUNIT,9066) (WORKID(I), WAVEV(I),I=1+120*(N-1),120*N)
         END IF

 500  CONTINUE

 9058 FORMAT(43X,'*** SOURCE CONTRIBUTIONS FOR EVENT: ',
     &       A8,' ***'//1X,'---> AVE. PER.: ',I3,' HRS;',
     &       '  END DATE:',I10,';  LOCATION (XR,YR,ZELEV,ZFLAG):',
     &       4F11.2,' (M)'/)
 9068 FORMAT(1X,'GROUP ID: ',A8,1X,'OF SOURCES: ',10(A8,', ')/
     &       12x,12(A8,', ')/12x,12(A8,', '))
 9070 FORMAT(/3X,'*** GROUP VALUE = ',F14.5,' ***'/)
 9062 FORMAT(3(' SOURCE ID     CONTRIBUTION ',8X)/
     &       3(' ---------     ------------ ',8X))
 9066 FORMAT(3(2X,A8,4X,F13.5,9X:))

      RETURN
      END

      SUBROUTINE PRTDET
C***********************************************************************
C                 PRTDET Module of ISC2 Model - EVENT
C
C        PURPOSE: Print Out The Source Contribution Data
C                 To The Event
C
C        PROGRAMMER: Jeff Wang, Roger Brode
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Arrays of Source Parameters
C                 Arrays of Model Results
C
C        OUTPUTS: Printed Model Outputs
C
C        CALLED FROM:   OUTPUT
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'
      DIMENSION WAVEV(NSRC), WHRVAL(24,NSRC)

C     Variable Initializations
      MODNAM = 'PRTDET'

C     Set Up The Printing Work Array
      INGRP = 0
      DO 210 ISRC = 1, NUMSRC
         IF (IGROUP(ISRC,IDXEV(IEVENT)) .EQ. 1) THEN
            INGRP = INGRP + 1
            WORKID(INGRP) = SRCID(ISRC)
            WAVEV(INGRP) = AVEVAL(ISRC)
            DO 211 IHR = ISTAHR, IENDHR
               WHRVAL(IHR,INGRP) = HRVALS(IHR,ISRC)
 211        CONTINUE
         END IF
 210  CONTINUE

C     Set Number of Sources Per Page, NSPP
      NSPP = 8
C     Calculate Number of Pages for This Event (NSPP Sources per Page)
      NPAGE = 1 + INT((INGRP-1)/NSPP)
      DO 300 N = 1, NPAGE
         CALL HEADER
         WRITE(IOUNIT,9058) EVNAME(IEVENT),EVAPER(IEVENT),
     &             EVDATE(IEVENT),AXR(IEVENT),AYR(IEVENT),
     &             AZELEV(IEVENT),AZFLAG(IEVENT)

         IF (N .EQ. NPAGE) THEN
C           Print Out The Values for the Last Page
            WRITE(IOUNIT,9068) EVGRP(IEVENT), (WORKID(I),
     &                                         I=1+NSPP*(N-1),INGRP)
            WRITE(IOUNIT,9066)

C           Print Out The Source Contributions for the Last Page
            DO 1003 I = ISTAHR, IENDHR
               WRITE(IOUNIT,9062) I,GRPVAL(I),(WHRVAL(I,J),
     &                                         J=1+NSPP*(N-1),INGRP)
 1003       CONTINUE
            WRITE(IOUNIT,9064) GRPAVE,(WAVEV(I),I=1+NSPP*(N-1),INGRP)
         ELSE
C           Print Out The Values for the Current Page
            WRITE(IOUNIT,9068) EVGRP(IEVENT), (WORKID(I),
     &                                         I=1+NSPP*(N-1),NSPP*N)
            WRITE(IOUNIT,9066)

C           Print Out The Source Contributions for the Current Page
            DO 1005 I = ISTAHR, IENDHR
               WRITE(IOUNIT,9062) I,GRPVAL(I),(WHRVAL(I,J),
     &                                         J=1+NSPP*(N-1),NSPP*N)
 1005       CONTINUE
            WRITE(IOUNIT,9064) GRPAVE,(WAVEV(I),I=1+NSPP*(N-1),NSPP*N)
         END IF

         IF (N .EQ. 1) THEN
C           Write Out the Meteorology Data
            NEWMET = .TRUE.
            DO 1010 IHOUR = ISTAHR, IENDHR
               AFV   = AAFVR(IHOUR)
               UREF  = AUREF(IHOUR)
               TA    = ATA(IHOUR)
               KST   = IKST(IHOUR)
               ZIRUR = AZI(1,IHOUR)
               ZIURB = AZI(2,IHOUR)
C              Retrieve Appropriate Mixing Height
               IF (RURAL) THEN
                  ZI = ZIRUR
               ELSE IF (URBAN) THEN
                  ZI = ZIURB
               END IF
               IF (METFRM .EQ. 'CARD') THEN
                  P    = APROF(IHOUR)
                  DTDZ = ADTDZ(IHOUR)
               END IF
C              Write Out The Meteorology Data
               CALL METDET
 1010       CONTINUE
         END IF
 300  CONTINUE

 9058 FORMAT(43X,'*** SOURCE CONTRIBUTIONS FOR EVENT: ',
     &       A8,' ***'/1X,'---> AVE. PER.: ',I3,' HRS;',
     &       '  END DATE:',I10,';  LOCATION (XR,YR,ZELEV,ZFLAG):',
     &       4F11.2,' (M)')
 9068 FORMAT(1X,'HOUR GROUP:',A8,' OF',3X,A8,7(6X,A8:))
 9066 FORMAT(65('- '))
 9062 FORMAT(1X,I3,2X,9(1X,F13.5:))
 9064 FORMAT(65('- ')/1X,'AVER:',9(1X,F13.5:))

      RETURN
      END

      SUBROUTINE METDET
C***********************************************************************
C                 METDET Module of ISC2 Model - EVENT
C
C        PURPOSE: Print Out The Details Of The Meteorology Data
C
C        PROGRAMMER: Jeff Wang
C
C        DATE:    March 2, 1992
C
C        INPUTS:  Meteorology Input Data
C
C        OUTPUTS: Printed Model Outputs
C
C        CALLED FROM:   PRTDET
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'METDET'

C     Meteorology Data Summary
      IF (NEWMET) THEN
         NEWMET = .FALSE.
         IF (METFRM .EQ. 'CARD') THEN
            WRITE(IOUNIT,9024)
         ELSE
            WRITE(IOUNIT,9025)
         END IF
      END IF
      IF (METFRM .EQ. 'CARD') THEN
         WRITE(IOUNIT,9031) IYEAR,IMONTH,IDAY,IHOUR,AFV,
     &         UREF,TA,KST,ZI,P,DTDZ
      ELSE
         WRITE(IOUNIT,9032) IYEAR,IMONTH,IDAY,IHOUR,AFV,
     &         UREF,TA,KST,ZI
      END IF

 9024 FORMAT(1X,'** METEOROLOGICAL DATA FOR THE EVENT **-->',1X,
     &       'YEAR',2X,'MONTH',2X,'DAY',2X,'HOUR',5X,'AFV',
     &       4X,'UREF',3X,'TEMP',4X,'KST',2X,'   ZI ',2X,
     &       'PROF ',2X,'DTDZ')
 9025 FORMAT(1X,'** METEOROLOGICAL DATA FOR THE EVENT **-->',1X,
     &       'YEAR',2X,'MONTH',2X,'DAY',2X,'HOUR',5X,'AFV',
     &       4X,'UREF',3X,'TEMP',4X,'KST',2X,'   ZI ')
 9031 FORMAT(45X,4(I2,4X),F6.1,1X,F6.2,1X,F6.1,1X,4X,I1,4X,F6.1,
     &       2(1X,F6.3))
 9032 FORMAT(45X,4(I2,4X),F6.1,1X,F6.2,1X,F6.1,1X,4X,I1,4X,F6.1)

      RETURN
      END

      SUBROUTINE FLUSH
C***********************************************************************
C                 Module FLUSH of ISC2 Model - EVENT
C
C        PURPOSE: To Flush AVEVAL and HRVALS Array
C
C        PROGRAMMER: Todd Hawes, Roger Brode and Jeff Wang
C
C        DATE:    March 2, 1992
C
C        INPUTS:  AVEVAL, HRVALS
C
C        OUTPUTS: Flushed AVEVAL and HRVALS
C
C        CALLED FROM:  MAIN
C***********************************************************************

C     Variable Declarations
      INCLUDE 'EVMAIN1.INC'
      INCLUDE 'EVMAIN2.INC'
      INCLUDE 'EVMAIN3.INC'

C     Variable Initializations
      MODNAM = 'FLUSH'

C     Flush the Hourly Value
      DO I = 1, NUMTYP
         HRVAL(I) = 0.0
      END DO

C     Flush the Group Values
      GRPAVE = 0.0
      DO 1000 IHOUR = 1, NHR
         GRPVAL(IHOUR) = 0.0
 1000 CONTINUE

C     Flush the Block Average Calculations
      DO 2500 ISRC = 1, NUMSRC
         AVEVAL(ISRC) = 0.0
         DO 2000 IHOUR = 1, NHR
            HRVALS(IHOUR,ISRC) = 0.0
 2000    CONTINUE
 2500 CONTINUE

      RETURN
      END
